(function ($) {

	'use strict';

	var SiPremiumTempsData = window.SiPremiumTempsData || {},
		SiPremiumEditor,
		SiPremiumEditorViews,
		SiPremiumControlsViews,
		SiPremiumModules;

	SiPremiumEditorViews = {

		ModalLayoutView: null,
		ModalHeaderView: null,
		ModalHeaderInsertButton: null,
		ModalLoadingView: null,
		ModalBodyView: null,
		ModalErrorView: null,
		LibraryCollection: null,
		KeywordsModel: null,
		ModalCollectionView: null,
		ModalTabsCollection: null,
		ModalTabsCollectionView: null,
		FiltersCollectionView: null,
		FiltersItemView: null,
		ModalTabsItemView: null,
		ModalTemplateItemView: null,
		ModalInsertTemplateBehavior: null,
		ModalTemplateModel: null,
		CategoriesCollection: null,
		ModalPreviewView: null,
		ModalHeaderBack: null,
		ModalHeaderLogo: null,
		KeywordsView: null,
		TabModel: null,
		CategoryModel: null,

		init: function () {
			var self = this;

			self.ModalTemplateModel = Backbone.Model.extend({
				defaults: {
					template_id: 0,
					name: '',
					title: '',
					thumbnail: '',
					preview: '',
					source: '',
					categories: [],
					keywords: []
				}
			});

			self.ModalHeaderView = Marionette.LayoutView.extend({

				id: 'si-premium-template-modal-header',
				template: '#tmpl-si-premium-template-modal-header',

				ui: {
					closeModal: '#si-premium-template-modal-header-close-modal'
				},

				events: {
					'click @ui.closeModal': 'onCloseModalClick'
				},

				regions: {
					headerLogo: '#si-premium-template-modal-header-logo-area',
					headerTabs: '#si-premium-template-modal-header-tabs',
					headerActions: '#si-premium-template-modal-header-actions'
				},

				onCloseModalClick: function () {
					SiPremiumEditor.closeModal();
				}

			});

			self.TabModel = Backbone.Model.extend({
				defaults: {
					slug: '',
					title: ''
				}
			});

			self.LibraryCollection = Backbone.Collection.extend({
				model: self.ModalTemplateModel
			});

			self.ModalTabsCollection = Backbone.Collection.extend({
				model: self.TabModel
			});

			self.CategoryModel = Backbone.Model.extend({
				defaults: {
					slug: '',
					title: ''
				}
			});

			self.KeywordsModel = Backbone.Model.extend({
				defaults: {
					keywords: {}
				}
			});

			self.CategoriesCollection = Backbone.Collection.extend({
				model: self.CategoryModel
			});

			self.KeywordsView = Marionette.ItemView.extend({
				id: 'elementor-template-library-filter',
				template: '#tmpl-si-premium-template-modal-keywords',
				ui: {
					keywords: '.si-premium-library-keywords'
				},

				events: {
					'change @ui.keywords': 'onSelectKeyword'
				},

				onSelectKeyword: function (event) {
					var selected = event.currentTarget.selectedOptions[0].value;
					SiPremiumEditor.setFilter('keyword', selected);
				},

				onRender: function () {
					var $filters = this.$('.si-premium-library-keywords');
					$filters.select2({
						placeholder: 'Choose Widget',
						allowClear: true,
						width: 250
					});
				}
			});

			self.ModalPreviewView = Marionette.ItemView.extend({

				template: '#tmpl-si-premium-template-modal-preview',

				id: 'si-premium-templatate-item-preview-wrap',

				ui: {
					iframe: 'iframe',
					notice: '.si-premium-template-item-notice'
				},


				onRender: function () {

					if (null !== this.getOption('notice')) {
						if (this.getOption('notice').length) {
							var message = "";
							if (-1 !== this.getOption('notice').indexOf("facebook")) {
								message += "<p>Please login with your Facebook account in order to get your Facebook Reviews.</p>";
							} else if (-1 !== this.getOption('notice').indexOf("google")) {
								message += "<p>You need to add your Google API key from Dashboard -> Premium Add-ons for Elementor -> Google Maps</p>";
							} else if (-1 !== this.getOption('notice').indexOf("form")) {
								message += "<p>You need to have <a href='https://wordpress.org/plugins/contact-form-7/' target='_blank'>Contact Form 7 plugin</a> installed and active.</p>";
							}

							this.ui.notice.html('<div><p><strong>Important!</strong></p>' + message + '</div>');
						}
					}

					this.ui.iframe.attr('src', this.getOption('url'));

				}
			});

			self.ModalHeaderBack = Marionette.ItemView.extend({

				template: '#tmpl-si-premium-template-modal-header-back',

				id: 'si-premium-template-modal-header-back',

				ui: {
					button: 'button'
				},

				events: {
					'click @ui.button': 'onBackClick',
				},

				onBackClick: function () {
					SiPremiumEditor.setPreview('back');
				}

			});

			self.ModalHeaderLogo = Marionette.ItemView.extend({

				template: '#tmpl-si-premium-template-modal-header-logo',

				id: 'si-premium-template-modal-header-logo'

			});

			self.ModalBodyView = Marionette.LayoutView.extend({

				id: 'si-premium-template-library-content',

				className: function () {
					return 'library-tab-' + SiPremiumEditor.getTab();
				},

				template: '#tmpl-si-premium-template-modal-content',

				regions: {
					contentTemplates: '.si-premium-templates-list',
					contentFilters: '.si-premium-filters-list',
					contentKeywords: '.si-premium-keywords-list'
				}

			});

			self.ModalInsertTemplateBehavior = Marionette.Behavior.extend({
				ui: {
					insertButton: '.si-premium-template-insert'
				},

				events: {
					'click @ui.insertButton': 'onInsertButtonClick'
				},

				onInsertButtonClick: function () {

					var templateModel = this.view.model,
						innerTemplates = templateModel.attributes.dependencies,
						isPro = templateModel.attributes.pro,
						innerTemplatesLength = Object.keys(innerTemplates).length,
						options = {};

					SiPremiumEditor.layout.showLoadingView();
					if (innerTemplatesLength > 0) {
						for (var key in innerTemplates) {
							$.ajax({
								url: ajaxurl,
								type: 'post',
								dataType: 'json',
								data: {
									action: 'si_premium_inner_template',
									template: innerTemplates[key],
									tab: SiPremiumEditor.getTab()
								}
							});
						}
					}

					if ("valid" === SiPremiumTempsData.license.status || !isPro) {

						elementor.templates.requestTemplateContent(
							templateModel.get('source'),
							templateModel.get('template_id'), {
							data: {
								tab: SiPremiumEditor.getTab(),
								page_settings: false
							},
							success: function (data) {

								if (!data.license) {
									SiPremiumEditor.layout.showLicenseError();
									return;
								}

								console.log("%c Template Inserted Successfully!!", "color: #7a7a7a; background-color: #eee;");

								SiPremiumEditor.closeModal();

								elementor.channels.data.trigger('template:before:insert', templateModel);

								if (null !== SiPremiumEditor.atIndex) {
									options.at = SiPremiumEditor.atIndex;
								}

								elementor.previewView.addChildModel(data.content, options);

								elementor.channels.data.trigger('template:after:insert', templateModel);
								jQuery("#elementor-panel-saver-button-save-options, #elementor-panel-saver-button-publish").removeClass("elementor-disabled");
								SiPremiumEditor.atIndex = null;

							},
							error: function (err) {
								console.log(err);
							}
						}
						);
					} else {
						SiPremiumEditor.layout.showLicenseError();
					}
				}
			});

			self.ModalHeaderInsertButton = Marionette.ItemView.extend({

				template: '#tmpl-si-premium-template-modal-insert-button',

				id: 'si-premium-template-modal-insert-button',

				behaviors: {
					insertTemplate: {
						behaviorClass: self.ModalInsertTemplateBehavior
					}
				}

			});

			self.FiltersItemView = Marionette.ItemView.extend({

				template: '#tmpl-si-premium-template-modal-filters-item',

				className: function () {
					return 'si-premium-template-filter-item';
				},

				ui: function () {
					return {
						filterLabels: '.si-premium-template-filter-label'
					};
				},

				events: function () {
					return {
						'click @ui.filterLabels': 'onFilterClick'
					};
				},

				onFilterClick: function (event) {

					var $clickedInput = jQuery(event.target);
					jQuery('.si-premium-library-keywords').val('');
					SiPremiumEditor.setFilter('category', $clickedInput.val());
					SiPremiumEditor.setFilter('keyword', '');
				}

			});

			self.ModalTabsItemView = Marionette.ItemView.extend({

				template: '#tmpl-si-premium-template-modal-tabs-item',

				className: function () {
					return 'elementor-template-library-menu-item';
				},

				ui: function () {
					return {
						tabsLabels: 'label',
						tabsInput: 'input'
					};
				},

				events: function () {
					return {
						'click @ui.tabsLabels': 'onTabClick'
					};
				},

				onRender: function () {
					if (this.model.get('slug') === SiPremiumEditor.getTab()) {
						this.ui.tabsInput.attr('checked', 'checked');
					}
				},

				onTabClick: function (event) {

					var $clickedInput = jQuery(event.target);
					SiPremiumEditor.setTab($clickedInput.val());
					SiPremiumEditor.setFilter('keyword', '');
				}

			});

			self.FiltersCollectionView = Marionette.CompositeView.extend({

				id: 'si-premium-template-library-filters',

				template: '#tmpl-si-premium-template-modal-filters',

				childViewContainer: '#si-premium-modal-filters-container',

				getChildView: function (childModel) {
					return self.FiltersItemView;
				}

			});

			self.ModalTabsCollectionView = Marionette.CompositeView.extend({

				template: '#tmpl-si-premium-template-modal-tabs',

				childViewContainer: '#si-premium-modal-tabs-items',

				initialize: function () {
					this.listenTo(SiPremiumEditor.channels.layout, 'tamplate:cloned', this._renderChildren);
				},

				getChildView: function (childModel) {
					return self.ModalTabsItemView;
				}

			});

			self.ModalTemplateItemView = Marionette.ItemView.extend({

				template: '#tmpl-si-premium-template-modal-item',

				className: function () {

					var urlClass = ' premium-template-has-url',
						sourceClass = ' elementor-template-library-template-',
						proTemplate = '';

					if ('' === this.model.get('preview')) {
						urlClass = ' premium-template-no-url';
					}

					sourceClass += 'remote';

					if (this.model.get('pro')) {
						proTemplate = ' premium-template-pro';
					}

					return 'elementor-template-library-template' + sourceClass + urlClass + proTemplate;
				},

				ui: function () {
					return {
						previewButton: '.elementor-template-library-template-preview',
					};
				},

				events: function () {
					return {
						'click @ui.previewButton': 'onPreviewButtonClick',
					};
				},

				onPreviewButtonClick: function () {

					if ('' === this.model.get('url')) {
						return;
					}

					SiPremiumEditor.setPreview(this.model);
				},

				behaviors: {
					insertTemplate: {
						behaviorClass: self.ModalInsertTemplateBehavior
					}
				}
			});

			self.ModalCollectionView = Marionette.CompositeView.extend({

				template: '#tmpl-si-premium-template-modal-templates',

				id: 'si-premium-template-library-templates',

				childViewContainer: '#si-premium-modal-templates-container',

				initialize: function () {

					this.listenTo(SiPremiumEditor.channels.templates, 'filter:change', this._renderChildren);
				},

				filter: function (childModel) {

					var filter = SiPremiumEditor.getFilter('category'),
						keyword = SiPremiumEditor.getFilter('keyword');

					if (!filter && !keyword) {
						return true;
					}

					if (keyword && !filter) {
						return _.contains(childModel.get('keywords'), keyword);
					}

					if (filter && !keyword) {
						return _.contains(childModel.get('categories'), filter);
					}

					return _.contains(childModel.get('categories'), filter) && _.contains(childModel.get('keywords'), keyword);

				},

				getChildView: function (childModel) {
					return self.ModalTemplateItemView;
				},

				onRenderCollection: function () {

					var container = this.$childViewContainer,
						items = this.$childViewContainer.children(),
						tab = SiPremiumEditor.getTab();

					if ('section' === tab || 'page' === tab || 'local' === tab) {
						return;
					}

					// Wait for thumbnails to be loaded
					container.imagesLoaded(function () { }).done(function () {
						self.masonry.init({
							container: container,
							items: items
						});
					});
				}

			});

			self.ModalLayoutView = Marionette.LayoutView.extend({

				el: '#si-premium-template-modal',

				regions: SiPremiumTempsData.modalRegions,

				initialize: function () {

					this.getRegion('modalHeader').show(new self.ModalHeaderView());
					this.listenTo(SiPremiumEditor.channels.tabs, 'filter:change', this.switchTabs);
					this.listenTo(SiPremiumEditor.channels.layout, 'preview:change', this.switchPreview);

				},

				switchTabs: function () {
					this.showLoadingView();
					SiPremiumEditor.setFilter('keyword', '');
					SiPremiumEditor.requestTemplates(SiPremiumEditor.getTab());
				},

				switchPreview: function () {

					var header = this.getHeaderView(),
						preview = SiPremiumEditor.getPreview();

					var filter = SiPremiumEditor.getFilter('category'),
						keyword = SiPremiumEditor.getFilter('keyword');

					if ('back' === preview) {
						header.headerLogo.show(new self.ModalHeaderLogo());
						header.headerTabs.show(new self.ModalTabsCollectionView({
							collection: SiPremiumEditor.collections.tabs
						}));

						header.headerActions.empty();
						SiPremiumEditor.setTab(SiPremiumEditor.getTab());

						if ('' != filter) {
							SiPremiumEditor.setFilter('category', filter);
							jQuery('#si-premium-modal-filters-container').find("input[value='" + filter + "']").prop('checked', true);

						}

						if ('' != keyword) {
							SiPremiumEditor.setFilter('keyword', keyword);
						}

						return;
					}

					if ('initial' === preview) {
						header.headerActions.empty();
						header.headerLogo.show(new self.ModalHeaderLogo());
						return;
					}

					this.getRegion('modalContent').show(new self.ModalPreviewView({
						'preview': preview.get('preview'),
						'url': preview.get('url'),
						'notice': preview.get('notice')
					}));

					header.headerLogo.empty();
					header.headerTabs.show(new self.ModalHeaderBack());
					header.headerActions.show(new self.ModalHeaderInsertButton({
						model: preview
					}));

				},

				getHeaderView: function () {
					return this.getRegion('modalHeader').currentView;
				},

				getContentView: function () {
					return this.getRegion('modalContent').currentView;
				},

				showLoadingView: function () {
					this.modalContent.show(new self.ModalLoadingView());
				},

				showLicenseError: function () {
					this.modalContent.show(new self.ModalErrorView());
				},

				showTemplatesView: function (templatesCollection, categoriesCollection, keywords) {

					this.getRegion('modalContent').show(new self.ModalBodyView());

					var contentView = this.getContentView(),
						header = this.getHeaderView(),
						keywordsModel = new self.KeywordsModel({
							keywords: keywords
						});

					SiPremiumEditor.collections.tabs = new self.ModalTabsCollection(SiPremiumEditor.getTabs());

					header.headerTabs.show(new self.ModalTabsCollectionView({
						collection: SiPremiumEditor.collections.tabs
					}));

					contentView.contentTemplates.show(new self.ModalCollectionView({
						collection: templatesCollection
					}));

					contentView.contentFilters.show(new self.FiltersCollectionView({
						collection: categoriesCollection
					}));

					contentView.contentKeywords.show(new self.KeywordsView({
						model: keywordsModel
					}));

				}

			});

			self.ModalLoadingView = Marionette.ItemView.extend({
				id: 'si-premium-template-modal-loading',
				template: '#tmpl-si-premium-template-modal-loading'
			});

			self.ModalErrorView = Marionette.ItemView.extend({
				id: 'si-premium-template-modal-loading',
				template: '#tmpl-si-premium-template-modal-error'
			});

		},

		masonry: {

			self: {},
			elements: {},

			init: function (settings) {

				var self = this;
				self.settings = $.extend(self.getDefaultSettings(), settings);
				self.elements = self.getDefaultElements();

				self.run();
			},

			getSettings: function (key) {
				if (key) {
					return this.settings[key];
				} else {
					return this.settings;
				}
			},

			getDefaultSettings: function () {
				return {
					container: null,
					items: null,
					columnsCount: 3,
					verticalSpaceBetween: 30
				};
			},

			getDefaultElements: function () {
				return {
					$container: jQuery(this.getSettings('container')),
					$items: jQuery(this.getSettings('items'))
				};
			},

			run: function () {
				var heights = [],
					distanceFromTop = this.elements.$container.position().top,
					settings = this.getSettings(),
					columnsCount = settings.columnsCount;

				distanceFromTop += parseInt(this.elements.$container.css('margin-top'), 10);

				this.elements.$container.height('');

				this.elements.$items.each(function (index) {
					var row = Math.floor(index / columnsCount),
						indexAtRow = index % columnsCount,
						$item = jQuery(this),
						itemPosition = $item.position(),
						itemHeight = $item[0].getBoundingClientRect().height + settings.verticalSpaceBetween;

					if (row) {
						var pullHeight = itemPosition.top - distanceFromTop - heights[indexAtRow];
						pullHeight -= parseInt($item.css('margin-top'), 10);
						pullHeight *= -1;
						$item.css('margin-top', pullHeight + 'px');
						heights[indexAtRow] += itemHeight;
					} else {
						heights.push(itemHeight);
					}
				});

				this.elements.$container.height(Math.max.apply(Math, heights));
			}
		}

	};

	SiPremiumControlsViews = {

		PremiumSearchView: null,

		init: function () {

			var self = this;

			self.PremiumSearchView = window.elementor.modules.controls.BaseData.extend({

				onReady: function () {

					var action = this.model.attributes.action,
						queryParams = this.model.attributes.query_params;

					this.ui.select.find('option').each(function (index, el) {
						$(this).attr('selected', true);
					});

					this.ui.select.select2({
						ajax: {
							url: function () {

								var query = '';

								if (queryParams.length > 0) {
									$.each(queryParams, function (index, param) {

										if (window.elementor.settings.page.model.attributes[param]) {
											query += '&' + param + '=' + window.elementor.settings.page.model.attributes[param];
										}
									});
								}

								return ajaxurl + '?action=' + action + query;
							},
							dataType: 'json'
						},
						placeholder: 'Please enter 3 or more characters',
						minimumInputLength: 3
					});

				},

				onBeforeDestroy: function () {

					if (this.ui.select.data('select2')) {
						this.ui.select.select2('destroy');
					}

					this.$el.remove();
				}

			});

			window.elementor.addControlView('premium_search', self.PremiumSearchView);

		}

	};


	SiPremiumModules = {

		getDataToSave: function (data) {
			data.id = window.elementor.config.post_id;
			return data;
		},

		init: function () {
			if (window.elementor.settings.premium_template) {
				window.elementor.settings.premium_template.getDataToSave = this.getDataToSave;
			}

			if (window.elementor.settings.premium_page) {
				window.elementor.settings.premium_page.getDataToSave = this.getDataToSave;
				window.elementor.settings.premium_page.changeCallbacks = {
					custom_header: function () {
						this.save(function () {
							elementor.reloadPreview();

							elementor.once('preview:loaded', function () {
								elementor.getPanelView().setPage('premium_page_settings');
							});
						});
					},
					custom_footer: function () {
						this.save(function () {
							elementor.reloadPreview();

							elementor.once('preview:loaded', function () {
								elementor.getPanelView().setPage('premium_page_settings');
							});
						});
					}
				};
			}

		}

	};

	SiPremiumEditor = {

		modal: false,
		layout: false,
		collections: {},
		tabs: {},
		defaultTab: '',
		channels: {},
		atIndex: null,

		init: function () {

			window.elementor.on(
				'document:loaded',
				window._.bind(SiPremiumEditor.onPreviewLoaded, SiPremiumEditor)
			);

			SiPremiumEditorViews.init();
			SiPremiumControlsViews.init();
			SiPremiumModules.init();

		},

		onPreviewLoaded: function () {

			this.initPremTempsButton();

			window.elementor.$previewContents.on(
				'click.addPremiumTemplate',
				'.si-premium-template-add-section-btn',
				_.bind(this.showTemplatesModal, this)
			);

			this.channels = {
				templates: Backbone.Radio.channel('PREMIUM_EDITOR:templates'),
				tabs: Backbone.Radio.channel('PREMIUM_EDITOR:tabs'),
				layout: Backbone.Radio.channel('PREMIUM_EDITOR:layout'),
			};

			this.tabs = SiPremiumTempsData.tabs;
			this.defaultTab = SiPremiumTempsData.defaultTab;

		},

		initPremTempsButton: function () {

			var $addNewSection = window.elementor.$previewContents.find('.elementor-add-new-section'),
				addPremiumTemplate = "<div class='elementor-add-section-area-button bg-dark si-premium-template-add-section-btn' title='Add Premium Template'><svg width='20' height='20' viewBox='0 0 24 24' fill='none' xmlns='http://www.w3.org/2000/svg'><path fill-rule='evenodd' clip-rule='evenodd' d='M17.9932 12.07C17.5078 12.1986 17.007 12.3159 16.4905 12.4143V12.7776V13.8975V15.377V16.8564V18.7369V22.3692V23.9962L17.9932 22.9935L19.4959 21.9909L20.9985 20.992L22.5012 19.9931V18.3623V15.0213V13.4094V11.7749C22.0314 12.0473 21.5305 12.3008 20.9985 12.5354C20.5171 12.7473 20.0162 12.9403 19.4959 13.1181V14.6391C20.0123 14.4726 20.5132 14.2948 20.9985 14.0981V15.6532V19.365L19.492 20.3639L17.9893 21.3628V16.5537V15.0591V13.5646V12.7738V12.07H17.9932ZM16.4905 8.04793C17.0303 7.94198 17.5311 7.82469 17.9932 7.68848V7.03768V5.21772V3.59073V3.25398V1.82753C18.5329 1.98644 19.0377 2.16806 19.4959 2.36481C19.5658 2.3913 19.6279 2.42157 19.6939 2.45184C20.1831 2.67508 20.6219 2.92102 20.9985 3.18209C21.0063 3.18587 21.0102 3.18966 21.018 3.19723C21.9576 3.85937 22.4973 4.63881 22.4973 5.47123C22.4973 6.30743 21.9498 7.09065 20.9947 7.76037C20.5675 8.0555 20.0628 8.3317 19.492 8.57765C19.0338 8.7744 18.529 8.95223 17.9893 9.11493C17.5156 9.25493 17.0147 9.37601 16.4867 9.48573C16.0052 9.58033 15.5043 9.66357 14.984 9.72789C14.0366 9.84897 13.0348 9.90951 11.9942 9.90951C10.9536 9.90951 9.95179 9.84897 9.00437 9.72789V11.1884C9.95955 11.3095 10.9613 11.3738 11.9942 11.3738C13.0231 11.3738 14.0249 11.3095 14.984 11.1884C15.5004 11.1241 16.0013 11.0408 16.4867 10.9462C17.007 10.8403 17.5078 10.723 17.9893 10.583C18.5174 10.4354 19.0183 10.2652 19.492 10.0798C20.0356 9.86789 20.5365 9.6333 20.9947 9.37601C21.5693 9.05439 22.0741 8.70629 22.4973 8.3317C23.4564 7.48416 24 6.51175 24 5.47123C24 4.43071 23.4564 3.4583 22.4973 2.61075C22.4119 2.53508 22.3226 2.4594 22.2333 2.38751C21.8722 2.09617 21.4645 1.82753 21.0102 1.57402L20.9985 1.58159V1.56645C20.5404 1.30916 20.0356 1.07457 19.4959 0.862683C19.2474 0.764307 18.9833 0.673498 18.7193 0.58269C18.4824 0.503232 18.2417 0.431342 17.9971 0.359451C17.5117 0.223238 17.0108 0.10216 16.4905 0V0.58269V1.46051V2.89453V3.58695V4.58584V6.21283V6.57985V7.39335V8.04793ZM4.50413 10.076C3.96441 9.8641 3.45963 9.62951 3.00146 9.37222C2.42679 9.05061 1.92202 8.70251 1.49879 8.32792C0.543601 7.48416 0 6.50796 0 5.47123C0 4.43071 0.543601 3.4583 1.50267 2.61075C1.58809 2.53508 1.6774 2.4594 1.77059 2.38751C2.13169 2.09617 2.5394 1.82753 2.99369 1.57402L3.00534 1.58159V1.56645C3.46352 1.30916 3.96829 1.07457 4.50801 0.862683C4.7604 0.764307 5.02055 0.673498 5.28458 0.58269C5.51755 0.503232 5.76217 0.431342 6.0068 0.359451C6.48827 0.223238 6.98916 0.10216 7.50946 0V0.58269V1.46051V2.89453V3.58695V4.58584V6.21283V6.41715V12.4143C6.99304 12.3159 6.49215 12.2024 6.0068 12.07V6.8712V5.21394V3.58695V3.25398V1.82753C5.46708 1.98644 4.96619 2.16806 4.50413 2.36481C4.43812 2.3913 4.37211 2.42157 4.3061 2.45184C3.81686 2.67508 3.37809 2.92102 3.00534 3.18209C2.99757 3.18587 2.98981 3.18966 2.98592 3.19723C2.04239 3.85937 1.50267 4.63881 1.50267 5.47123C1.50267 6.30743 2.05015 7.09065 3.00534 7.76037C3.42857 8.0555 3.93334 8.3317 4.50801 8.57765V10.076H4.50413ZM7.50946 16.8564C7.00081 16.7694 6.49992 16.671 6.0068 16.5575V18.0255C6.0068 20.8898 6.0068 18.5023 6.0068 21.3665L4.50413 20.3639L3.00146 19.365V15.6532V14.0981C3.48681 14.291 3.9877 14.4726 4.50413 14.6391V13.1181C4.98948 13.2846 5.49037 13.4321 6.0068 13.5646C6.49604 13.6894 6.99693 13.7954 7.50946 13.8937C7.99871 13.9808 8.4996 14.0602 9.01213 14.1208C9.97897 14.2343 10.9769 14.2948 12.0019 14.2948C13.0231 14.2948 14.0249 14.2343 14.9917 14.1208V15.5888C14.021 15.6986 13.0231 15.7591 12.0019 15.7591C10.9807 15.7591 9.98285 15.6986 9.01213 15.5888C8.50348 15.5321 8.00259 15.4602 7.50946 15.3732C6.99693 15.2786 6.49604 15.1802 6.0068 15.0591C5.49426 14.9343 4.99337 14.7943 4.50413 14.6391V13.1181C3.98382 12.9403 3.48293 12.7473 3.00146 12.5354C2.47339 12.3008 1.9725 12.0473 1.49879 11.7749V13.4094V15.0213V18.3661V19.9968L3.00146 20.9957L4.50413 21.9946L6.0068 22.9973L7.50946 24V22.373C7.50946 19.1758 7.50946 21.2265 7.50946 18.0293V16.8564Z' fill='#B2B2B2'/></svg></div>",
				$addPremiumTemplate;

			if ($addNewSection.length && SiPremiumTempsData.PremiumTemplatesBtn) {
				$addPremiumTemplate = $(addPremiumTemplate).prependTo($addNewSection);
			}

			window.elementor.$previewContents.on(
				'click.addPremiumTemplate',
				'.elementor-editor-section-settings .elementor-editor-element-add',
				function () {

					var $this = $(this),
						$section = $this.closest('.elementor-top-section'),
						modelID = $section.data('model-cid');

					if (elementor.previewView.collection.length) {
						$.each(elementor.previewView.collection.models, function (index, model) {
							if (modelID === model.cid) {
								SiPremiumEditor.atIndex = index;
							}
						});
					}


					if (SiPremiumTempsData.PremiumTemplatesBtn) {
						setTimeout(function () {
							var $addNew = $section.prev('.elementor-add-section').find('.elementor-add-new-section');
							$addNew.prepend(addPremiumTemplate);
						}, 100);
					}

				}
			);

		},

		getFilter: function (name) {

			return this.channels.templates.request('filter:' + name);
		},

		setFilter: function (name, value) {
			this.channels.templates.reply('filter:' + name, value);
			this.channels.templates.trigger('filter:change');
		},

		getTab: function () {
			return this.channels.tabs.request('filter:tabs');
		},

		setTab: function (value, silent) {

			this.channels.tabs.reply('filter:tabs', value);

			if (!silent) {
				this.channels.tabs.trigger('filter:change');
			}

		},

		getTabs: function () {

			var tabs = [];

			_.each(this.tabs, function (item, slug) {
				tabs.push({
					slug: slug,
					title: item.title
				});
			});

			return tabs;
		},

		getPreview: function (name) {
			return this.channels.layout.request('preview');
		},

		setPreview: function (value, silent) {

			this.channels.layout.reply('preview', value);

			if (!silent) {
				this.channels.layout.trigger('preview:change');
			}
		},

		getKeywords: function () {

			var keywords = [];

			_.each(this.keywords, function (title, slug) {
				tabs.push({
					slug: slug,
					title: title
				});
			});

			return keywords;
		},

		showTemplatesModal: function () {

			this.getModal().show();

			if (!this.layout) {
				this.layout = new SiPremiumEditorViews.ModalLayoutView();
				this.layout.showLoadingView();
			}

			this.setTab(this.defaultTab, true);
			this.requestTemplates(this.defaultTab);
			this.setPreview('initial');

		},

		requestTemplates: function (tabName) {

			var self = this,
				tab = self.tabs[tabName];

			self.setFilter('category', false);

			if (tab && tab.data && tab.data.templates && tab.data.categories.templates && tab.data.categories) {
				self.layout.showTemplatesView(tab.data.templates, tab.data.categories, tab.data.keywords);
			} else {
				$.ajax({
					url: ajaxurl,
					type: 'get',
					dataType: 'json',
					data: {
						action: 'si_premium_get_templates',
						tab: tabName
					},
					success: function (response) {
						console.log("%cTemplates Retrieved Successfully!!", "color: #7a7a7a; background-color: #eee;");

						var templates = new SiPremiumEditorViews.LibraryCollection(response.data.templates),
							categories = new SiPremiumEditorViews.CategoriesCollection(response.data.categories);

						if( self.tabs[tabName] ) {
							self.tabs[tabName].data = {
								templates: templates,
								categories: categories,
								keywords: response.data.keywords
							};
						}

						self.layout.showTemplatesView(templates, categories, response.data.keywords);

					}
				});
			}

		},

		closeModal: function () {
			this.getModal().hide();
		},

		getModal: function () {

			if (!this.modal) {
				this.modal = elementor.dialogsManager.createWidget('lightbox', {
					id: 'si-premium-template-modal',
					className: 'elementor-templates-modal',
					closeButton: false
				});
			}

			return this.modal;

		}

	};

	$(window).on('elementor:init', SiPremiumEditor.init);

})(jQuery);