<?php
namespace HellixElementor\Modules\Carousel\Skins;

use Elementor;
use Elementor\Skin_Base;
use Elementor\Control_Media;
use Elementor\Utils;
use Elementor\Group_Control_Image_Size;
use Elementor\Controls_Manager;
use HellixElementor\Core\Utils as AR_Utils;
use Elementor\Icons_Manager;
use Elementor\Widget_Base;
use Elementor\Group_Control_Typography;
use Elementor\Core\Kits\Documents\Tabs\Global_Typography;
use Elementor\Core\Kits\Documents\Tabs\Global_Colors;
use Elementor\Repeater;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * Skin for Hero Style 9.
 */
class Hero_Style_9 extends Skin_Base {

	/**
	 * Get the name of the widget.
	 *
	 * @return string
	 */
	public function get_id() {
		return 'hero-caorusel-9';
	}

	/**
	 * Get the title of the skin.
	 *
	 * @return string
	 */
	public function get_title() {
		return esc_html__( 'Hero Carousel 9', 'hellix-elementor' );
	}

	/**
	 * Register Controls Action.
	 */
	protected function _register_controls_actions() {
		add_action( 'elementor/element/hx-hero-carousel/section_slides/after_section_end', [ $this, 'add_controls' ], 10 );
	}

	/**
	 * Update controls for removing column and caption controls.
	 *
	 * @param Elementor\Widget_Base $widget The widget settings.
	 */
	public function add_controls( $widget ) {
		$this->parent = $widget;
		$this->start_controls_section(
			'section_style_v9_icon',
			[
				'label' => esc_html__( 'Icon', 'hellix-elementor' ),

			]
		);

		$this->add_control(
			'social_list_v9',
			[
				'label'       => esc_html__( 'Icon List', 'hellix-elementor' ),
				'type'        => Controls_Manager::TEXTAREA,
				'placeholder' => esc_html__( 'link|value', 'hellix-elementor' ),
				'default'     => esc_html__( 'https://facebook.com', 'hellix-elementor' ),
				'description' => esc_html__( 'Enter the social profiles here. Each profile URL should be separated by a new line by hitting Enter button', 'hellix-elementor' ),
			]
		);

		$this->add_control(
			'social_icon_color_v9',
			[
				'label'     => esc_html__( 'Social Icon Color', 'hellix-elementor' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .hx-hero_carousel__icon' => 'color: {{VALUE}}',
				],
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'section_style_v9_copyrights',
			[
				'label' => esc_html__( 'Copyright', 'hellix-elementor' ),

			]
		);

		$this->add_control(
			'copyright_text',
			[
				'label'   => esc_html__( 'Copyright Text', 'hellix-elementor' ),
				'type'    => Controls_Manager::TEXT,
				'default' => esc_html__( '© 2022 Hellix. All rights reserved.', 'hellix-elementor' ),
			]
		);

		$this->add_control(
			'copyright_text_color_v9',
			[
				'label'     => esc_html__( 'Copyright Text Color', 'hellix-elementor' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .hx__copyright_color' => 'color: {{VALUE}}!important',
				],
			]
		);

		$this->end_controls_section();
	}

	/**
	 * Get render_profile_icons settings
	 */
	public function render_profile_icons() {
		$widget   = $this->parent;
		$settings = $widget->get_settings_for_display();

		$skin_control_ids = [
			'social_list_v9',
		];

		$skin_settings = [];

		foreach ( $skin_control_ids as $skin_control_id ) {
			$skin_settings[ $skin_control_id ] = $this->get_instance_value( $skin_control_id );
		}

		$hellix_social_icon = $skin_settings['social_list_v9'];

		if ( $hellix_social_icon ) {

			$profiles = explode( "\n", $hellix_social_icon );

			$social_networks = [
				'facebook.com'      => 'facebook',
				'linkedin.com'      => 'linkedin',
				'twitter.com'       => 'twitter',
				'instagram.com'     => 'instagram',
				'github.com'        => 'github',
				'dribbble.com'      => 'dribbble',
				'behance.com'       => 'behance',
				'stackoverflow.com' => 'stack-overflow',

			];

			if ( isset( $profiles ) ) {
				foreach ( $profiles as $social_profile ) {

					if ( empty( trim( $social_profile ) ) ) {
						continue;
					}
					$detail = explode( '|', $social_profile );
					if ( isset( $detail[1] ) ) {
						$class = ' ' . $detail[1];
					}

					$parse = parse_url( $detail[0] );
					$url   = isset( $parse['host'] ) ? $parse['host'] : '';

					if ( isset( $social_networks[ $url ] ) && ! empty( $url ) ) :

						$icon = isset( $class ) ? $social_networks[ $url ] . $class : $social_networks[ $url ];
						?>
					<a data-barba href="<?php echo esc_url( $social_profile ); ?>" class="<?php echo esc_attr( $icon ); ?> text-white">
						<i class="hx-hero_carousel__icon fa fa-<?php echo esc_attr( $social_networks[ $url ] ); ?>" aria-hidden="true"></i>
					</a>
						<?php
					endif;
				}
			}
		}
	}
	/**
	 * Print Slider
	 *
	 * @param  array $settings The Widget settings.
	 *
	 * @return void
	 */
	protected function print_slider( array $settings = null ) {

		$widget = $this->parent;

		if ( null === $settings ) {
			$settings = $widget->get_settings_for_display();
		}

		$copyright_text = $widget->get_settings_for_display( 'hero_caorusel_9_copyright_text' );

		$widget->add_render_attribute(
			'mainSlider',
			array(
				'class' => 'mainSlider -type-9 swiper-container js-mainSlider-type-9',
			)
		);
		?>
		<section data-anim-wrap <?php $widget->print_render_attribute_string( 'mainSlider' ); ?>>
			<div class="swiper-wrapper">
				<?php foreach ( $settings['slides'] as $slide ) : ?>
					<?php $this->print_slide( $slide, $settings, 'image-slide-' . $slide['_id'] ); ?>
				<?php endforeach; ?>
			</div>
			<?php if ( 'yes' === $settings['show_dots'] ) { ?>
				<?php $this->render_pagination( $settings['slides'] ); ?>
			<?php } ?>
			<?php $this->render_social_icon(); ?>
			<div class="mainSlider__scroll js-scroll md:d-none">
				<div class="mainSlider__scroll_item">
					Scroll
					<div class="mainSlider__scroll_icon">
						<i class="icon icon-right-arrow"></i>
					</div>
				</div>
			</div>
			<div class="mainSlider__copyright">
				<span class="text-white hx__copyright_color">
					<?php echo esc_attr( $copyright_text ); ?> 
				</span>
			</div>
		</section>
		<?php
	}
	/**
	 * Render Social Icons.
	 */
	public function render_social_icon() {
		?>
		<div class="mainSlider__socials">
			<div class="socials">
			<?php
				$this->render_profile_icons();
			?>
			</div>
		</div>
		<?php
	}

	/**
	 * Print the slide.
	 *
	 * @param  array $slide    The slide information.
	 * @param  array $settings The widget settings.
	 * @param  int   $index    The slide number.
	 * @return void
	 */
	protected function print_slide( array $slide, array $settings, $index ) {

		$widget        = $this->parent;
		$sub_title_css = $settings['sub_title_css'];
		$btn_txt       = $slide['btn_text'];
		$class_btn     = 'button__text_color button -' . $settings['button_type'];

		$widget->add_render_attribute( 'button-' . $index, 'class', $class_btn );
		if ( ! empty( $slide['btn_link']['url'] ) ) {
			$widget->add_link_attributes( 'button-' . $index, $slide['btn_link'] );
		}

		?>
		<div class="swiper-slide">
			<div data-parallax="0.6" class="mainSlider__image" data-swiper-parallax="50%">
				<?php echo wp_kses_post( $widget->get_slide_image_html( $slide, $index ) ); ?>
			</div>
			<div class="row align-items-center">
				<div class="mainSlider__content js-content">
					<div class="col-lg-9 col-md-11">
						<div class="mainSlider__subtitle hx-hero__sub_title js-all-item <?php echo esc_attr( $sub_title_css ); ?>">
							<?php echo esc_html( $slide['sub_title'] ); ?>
						</div>
						<?php $this->render_title( $settings, $slide, $index ); ?>
						<div class="mainSlider__button mt-40 js-all-item">
							<a <?php $widget->print_render_attribute_string( 'button-' . $index ); ?>><?php echo esc_html( $btn_txt ); ?>
							</a>
						</div>
					</div>
				</div>
			</div>
		</div>
		<?php
	}

	/**
	 * Render the title of the slide.
	 *
	 * @param  array $settings The Widget settings.
	 * @param  array $slide    The slide information.
	 * @param  int   $i        Index of the slide.
	 * @return void
	 */
	public function render_title( $settings, $slide, $i ) {

		$widget = $this->parent;
		$widget->add_render_attribute(
			'title_css' . $i,
			'class',
			[
				'hx-hero__title',
				'mainSlider__title',
				'text-white',
				'js-all-item',
				'mt-24 ',
				$settings['title_css'],
			]
		);

		$tag = $settings['title_tag'];

		?>
		<<?php echo esc_attr( $tag ); ?> <?php $widget->print_render_attribute_string( 'title_css' . $i ); ?>>
			<?php echo wp_kses_post( $slide['title'] ); ?>
		</<?php echo esc_attr( $tag ); ?>> 
		<?php
	}

	/**
	 * Render Pagination.
	 *
	 * @param  array $slides    The slide information.
	 */
	public function render_pagination( $slides ) {

		$count = count( $slides );

		if ( 0 !== $count ) {
			?>
		<div class="pagination ">
			<div class="pagination__current pagination_color__title">01</div>
			<div class="pagination__line js-pagination pagination_color__title"></div>
			<div class="pagination__total pagination_color__title">0<?php echo esc_html( $count ); ?> </div>
		</div>
			<?php
		}
	}

	/**
	 * Render the widget in the frontend.
	 */
	public function render() {
		$widget  = $this->parent;
		$hero_v9 = uniqid( 'hero-v9-' );
		$widget->add_render_attribute( 'mainSlider', 'id', $hero_v9 );
		$settings = $widget->get_settings_for_display();
		$this->print_slider( $settings );
		$this->render_script( $hero_v9 );
	}

	/**
	 * Render script in the editor.
	 *
	 * @param string $hero_v9 passing id.
	 */
	public function render_script( $hero_v9 ) {
		if ( Elementor\Plugin::$instance->editor->is_edit_mode() ) :
			?>
			<script type="text/javascript">
				
				 /**
				 * Editor Slider Load.
				 */
				var MainSlider9 = (function() {
					let sliderInstance;
					let currentIndex = 0;

					function sliderInit() {
						sliderInstance = new Swiper(document.getElementById( "<?php echo esc_attr( $hero_v9 ); ?>" ), {
						spaceBetween: 0,
						speed: 1000,
						parallax: true,
						direction: 'vertical',
						mousewheel: true,
						lazy: {
							loadPrevNext: true,
						},
						breakpoints: {
							575: {
							parallax: false,
							},
						},
						navigation: {
							prevEl: document.querySelector('#<?php echo esc_attr( $hero_v9 ); ?> .js-nav-prev'),
							nextEl: document.querySelector('#<?php echo esc_attr( $hero_v9 ); ?> .js-nav-next'),
						},
						pagination: {
							el: document.querySelector('#<?php echo esc_attr( $hero_v9 ); ?> .js-pagination'),
							type: 'progressbar',
							clickable: true
						},
						});
					}

					function sliderEvents() {
						sliderInstance.on('slideChangeTransitionEnd', function () {
						hideContent(sliderInstance.slides[currentIndex]);
						showContent(sliderInstance.slides[sliderInstance.activeIndex]);
						currentIndex = sliderInstance.activeIndex;
						});
					}

					function hideContent(slide) {
						const lines = slide.querySelectorAll('.js-title .split__line')
						const text = slide.querySelector('.js-text')
						const button = slide.querySelector('.js-button')

						gsap.timeline()
						.set(lines, {
							y: '100%',
						})
						.set(text, {
							opacity: 0,
							y: '30px',
						})
						.set(button, {
							opacity: 0,
							y: '30px',
						});
					}

					function showContent(slide) {
						const lines = slide.querySelectorAll('.js-title .split__line')
						const text = slide.querySelector('.js-text')
						const button = slide.querySelector('.js-button')

						gsap.timeline()
						.to(lines, {
							stagger: 0.1,
							duration: 0.9,
							ease: 'power3.out',
							y: '0%',
						})
						.to(text, {
							duration: 0.6,
							ease: 'power3.out',
							opacity: 1,
							y: '0%',
						}, ">-0.4")
						.to(button, {
							duration: 0.6,
							ease: 'power3.out',
							opacity: 1,
							y: '0%',
						}, ">-0.4");
					}

					function hideSlides() {
						const lines = document.querySelectorAll('#<?php echo esc_attr( $hero_v9 ); ?> .js-title .split__line')
						const text = document.querySelectorAll('#<?php echo esc_attr( $hero_v9 ); ?> .js-text')
						const button = document.querySelectorAll('#<?php echo esc_attr( $hero_v9 ); ?> .js-button')

						gsap.timeline()
						.set(lines, {
							y: '100%',
						})
						.set(text, {
							opacity: 0,
							y: '30px',
						})
						.set(button, {
							opacity: 0,
							y: '30px',
						});
					}

					function init() {
						if (!document.querySelector('#<?php echo esc_attr( $hero_v9 ); ?>')) return;
						sliderInit();
						hideSlides();
						sliderEvents();
					}

					return {
						init: init,
					}
					})();
				function container() {
						var animationContainer = document.querySelectorAll('[data-anim-wrap]');

						if (!animationContainer.length) {
							return;
						}
						
						for (let i = 0; i < animationContainer.length; i++) {
							const el = animationContainer[i];
						
							new ScrollMagic.Scene({
							offset: '160px',
							triggerElement: el,
							triggerHook: "onEnter",
							reverse: false,
							})
							.on('enter', function (event) {
							
							const animChilds = el.querySelectorAll('[data-anim-child]');
							el.classList.add('animated');
							animChilds.forEach(el => animateElement(el));
							
							})
							.addTo(App.SMcontroller)
						}

						}	
						MainSlider9.init();
						container();								
			</script>
			<?php
		endif;
	}

}
