<?php
namespace HellixElementor\Modules\Carousel\Skins;

use Elementor;
use Elementor\Skin_Base;
use Elementor\Control_Media;
use Elementor\Utils;
use Elementor\Group_Control_Image_Size;
use Elementor\Controls_Manager;
use HellixElementor\Core\Utils as HX_Utils;
use Elementor\Icons_Manager;
use Elementor\Widget_Base;
use Elementor\Repeater;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * Skin for Project Carousel.
 */
class Project_Style_1 extends Skin_Base {

	/**
	 * Get the id for the skin.
	 *
	 * @return string
	 */
	public function get_id() {
		return 'project-style-1';
	}

	/**
	 * Get the title for the skin.
	 *
	 * @return string
	 */
	public function get_title() {
		return esc_html__( 'Project Style 1', 'hellix-elementor' );
	}

	/**
	 * Hellix Portfolio Title Display.
	 *
	 * @param  int $i    The slide number.
	 * @return void
	 */
	protected function hellix_portfolio_title_display( $i ) {

		$widget    = $this->parent;
		$settings  = $widget->get_settings();
		$title_css = $settings['prj_title_css'];

		$widget->add_render_attribute( 'title' . $i, 'class', [ 'portfolioCard__title portfolio__title ' . $title_css ] );

		$show_title = $settings['show_title'];
		if ( 'yes' != $show_title ) {
			return;
		}
		$tag = $settings['title_tag_portfolio'];
		?>
		<<?php echo esc_attr( $tag ); ?> <?php $widget->print_render_attribute_string( 'title' . $i ); ?>>
			<?php the_title(); ?>
		</<?php echo esc_attr( $tag ); ?>>
		<?php
	}

	/**
	 * Hellix Portfolio Category Display.
	 *
	 * @param  int $i    The slide number.
	 * @return void
	 */
	protected function hellix_portfolio_category_display( $i ) {

		$widget             = $this->parent;
		$settings           = $widget->get_settings();
		$portfolio_category = hellix_portfolio_type();
		$category_css       = $settings['category_css'];
		$widget->add_render_attribute( 'category' . $i, 'class', [ 'portfolioCard__category portfolio__category ' . $category_css ] );
		?>
		<span <?php $widget->print_render_attribute_string( 'category' . $i ); ?>> 
			<?php echo esc_html( $portfolio_category ); ?>
		</span>
		<?php
	}

	/**
	 * Render Loop Start.
	 *
	 * @param  array $settings The Widget settings.
	 *
	 * @return void.
	 */
	protected function render_loop_start( $settings ) {

		$widget            = $this->parent;
		$gutter            = ! empty( $settings['prj_gutter']['size'] ) ? intval( $settings['prj_gutter']['size'] ) : 30;
		$padding_css       = 'yes' === $settings['padding_css'] ? 'layout-pt-sm' : '';
		$data_cursor_label = '';
		if ( 'yes' === $settings['prj_data_cursor'] ) {
			if ( ! empty( $settings['prj_cursor_label'] ) ) {
				$data_cursor_label = $settings['prj_cursor_label'];
			}
		}
		$widget->add_render_attribute(
			'sectionSlider',
			array(
				'class'           => 'sectionSlider js-sectionSlider',
				'data-gap'        => $gutter,
				'data-slider-col' => 'base-1 lg-1 md-1 sm-1',
			)
		);
		if ( 'yes' === $settings['prj_data_center'] ) {
			$widget->add_render_attribute(
				'sectionSlider',
				'data-center',
				''
			);
		}
		if ( 'yes' === $settings['prj_data_loop'] ) {
			$widget->add_render_attribute(
				'sectionSlider',
				'data-loop',
				''
			);
		}
		if ( 'yes' === $settings['prj_data_pagination'] ) {
			$widget->add_render_attribute(
				'sectionSlider',
				'data-pagination',
				''
			);
		}
		if ( 'yes' === $settings['prj_data_cursor'] ) {
			$widget->add_render_attribute(
				'sectionSlider',
				'data-cursor',
				''
			);
		}
		if ( 'yes' === $settings['prj_data_cursor'] ) {
			$widget->add_render_attribute(
				'sectionSlider',
				'data-cursor-label',
				$data_cursor_label
			);
		}
		$padding_class = 'row justify-content-center';
		$padding_class = ! empty( $padding_css ) ? $padding_class . ' ' . $padding_css : $padding_class;
		$widget->add_render_attribute( 'section-css', 'class', $padding_class );
		?>
		<div <?php $widget->print_render_attribute_string( 'section-css' ); ?>>
			<div class="col-lg-8">
				<div <?php $widget->print_render_attribute_string( 'sectionSlider' ); ?>>
		<?php
	}

	/**
	 * Render loop header.
	 */
	protected function render_loop_header() {
		?>
		<div class="swiper-wrapper">
		<?php
	}

	/**
	 * Render loop footer.
	 */
	protected function render_loop_footer() {
		?>
		</div> <!-- / .row -->
		<?php
	}

	/**
	 * Render loop end.
	 */
	protected function render_loop_end() {
		?>
			</div>
		</div><!-- / .col -->
	</div><!-- / .row -->
		<?php
	}

	/**
	 * Render Arrow Control.
	 */
	public function render_arrow_control() {
		?>
		
		<div class="sliderNav -portfolio-slider js-nav">
			<button class="sliderNav__item -prev js-prev pagination_color__title">
				<?php echo esc_html__( 'PREV', 'hellix-elementor' ); ?> 
			</button>
			<button class="sliderNav__item -next js-next pagination_color__title">
				<?php echo esc_html__( 'NEXT', 'hellix-elementor' ); ?> 
			</button>
		</div>
		<?php
	}

	/**
	 * Print Slider
	 *
	 * @param  array $settings The Widget settings.
	 *
	 * @return void
	 */
	public function print_slider( array $settings = null ) {

		$widget = $this->parent;

		$widget->query_posts( $settings );

		$query = $widget->get_query();
		if ( ! $query->found_posts ) {
			return;
		}
		$this->render_loop_start( $settings );
		if ( 'yes' == $settings['prj_show_arrows'] ) {
			$this->render_arrow_control();
		}
		$this->render_loop_header();
		$i = 0;
		// It's the global `wp_query` it self. and the loop was started from the theme.
		if ( $query->in_the_loop ) {
			$this->current_permalink = get_permalink();
			$this->render_project_post( $i );
			$i++;
		} else {
			while ( $query->have_posts() ) {
				$query->the_post();
				$this->current_permalink = get_permalink();
				$this->render_project_post( $i );
				$i++;
			}
		}
		wp_reset_postdata();
		$this->render_loop_footer();
		?>
			<div class="pagination -slider mt-48 js-pagination"></div>
			<?php
			$this->render_loop_end();
	}

	/**
	 * Render project post.
	 *
	 * @param  int $index    The slide number.
	 */
	protected function render_project_post( $index ) {

		$widget            = $this->parent;
		$settings          = $widget->get_settings();
		$data_cursor_label = '';
		if ( 'yes' === $settings['prj_data_cursor'] ) {
			if ( ! empty( $settings['prj_cursor_label'] ) ) {
				$data_cursor_label = $settings['prj_cursor_label'];
			}
		}
		?>
		<div class="swiper-slide">
			<a data-barba data-cursor data-cursor-label="<?php echo esc_attr( $data_cursor_label ); ?>" href="<?php echo esc_url( get_permalink() ); ?>" class="portfolio">
				<?php if ( has_post_thumbnail() ) : ?>
					<div class="portfolio__image">
						<div class="ratio ratio-16:9">
							<?php
							the_post_thumbnail(
								'full',
								[
									'class' => 'ratio-img swiper-lazy',
									'alt'   => 'project image',
								]
							);
							?>
											
							<div class="swiper-lazy-preloader"></div>
						</div>
					</div>
				<?php endif; ?>
				<div class="portfolio__content text-center">
					<!-- Category -->
					<?php $this->hellix_portfolio_category_display( $index ); ?>
					<!-- Heading -->
					<?php $this->hellix_portfolio_title_display( $index ); ?>
				</div>
			</a>
		</div>
		<?php
	}

	/**
	 * Render the widget in the frontend.
	 */
	public function render() {
		$widget   = $this->parent;
		$settings = $widget->get_settings_for_display();
		$this->print_slider( $settings );
		$widget->render_script();
	}

}
