<?php
namespace HellixElementor\Modules\Carousel\Widgets;

use Elementor\Controls_Manager;
use Elementor\Core\Kits\Documents\Tabs\Global_Colors;
use Elementor\Core\Kits\Documents\Tabs\Global_Typography;
use Elementor\Group_Control_Typography;
use HellixElementor\Modules\Carousel\Skins;
use Elementor\Repeater;
use Elementor\Utils;
use Elementor\Icons_Manager;
use Elementor\Group_Control_Image_Size;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 *  Hero Carousel.
 */
class Hero_Carousel extends Base {

	/**
	 * $_has_template_content.
	 *
	 * @var boolean
	 */
	protected $_has_template_content = false;

	/**
	 * Get the name of the widget.
	 *
	 * @return string
	 */
	public function get_name() {
		return 'hx-hero-carousel';
	}

	/**
	 * Get the title of the widget.
	 *
	 * @return string
	 */
	public function get_title() {
		return esc_html__( 'Hero Carousel', 'hellix-elementor' );
	}

	/**
	 * Get the icon for the widget.
	 *
	 * @return string
	 */
	public function get_icon() {
		return 'eicon-posts-carousel';
	}

	/**
	 * Get the keywords associated with the widget.
	 *
	 * @return array
	 */
	public function get_keywords() {
		return [ 'Hero', 'carousel', 'image' ];
	}

	/**
	 * Get the group for this widget.
	 *
	 * @return string
	 */
	public function get_group_name() {
		return 'carousel';
	}

	/**
	 * Print the slide.
	 *
	 * @param  array $slide         The slide information.
	 * @param  array $settings      The widget settings.
	 * @param  int   $element_key   The slide number.
	 * @return void
	 */
	protected function print_slide( array $slide, array $settings, $element_key ) {}

	/**
	 * Register controls for this widget.
	 */
	protected function register_skins() {
		$this->add_skin( new Skins\Hero_Style_1( $this ) );
		$this->add_skin( new Skins\Hero_Style_2( $this ) );
		$this->add_skin( new Skins\Hero_Style_3( $this ) );
		$this->add_skin( new Skins\Hero_Style_4( $this ) );
		$this->add_skin( new Skins\Hero_Style_5( $this ) );
		$this->add_skin( new Skins\Hero_Style_6( $this ) );
		$this->add_skin( new Skins\Hero_Style_7( $this ) );
		$this->add_skin( new Skins\Hero_Style_9( $this ) );
		$this->add_skin( new Skins\Hero_Style_10( $this ) );
	}

	/**
	 * Register controls for this widget.
	 */
	protected function register_controls() {
		parent::register_controls();
		$this->remove_control( 'section_navigation' );
		$this->remove_control( 'gutter' );
		$this->remove_control( 'slides_per_view' );
		$this->remove_control( 'arrow_color' );
		$this->remove_control( 'arrow_hover_color' );

		$this->start_controls_section(
			'section_title_style',
			[
				'label' => esc_html__( 'Title', 'hellix-elementor' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'title_color',
			[
				'label'     => esc_html__( 'Color', 'hellix-elementor' ),
				'type'      => Controls_Manager::COLOR,
				'default'   => '#ffffff',
				'selectors' => [
					'{{WRAPPER}} .hx-hero__title' => 'color: {{VALUE}} !important;',
				],
				'global'    => [
					'default' => Global_Colors::COLOR_TEXT,
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'     => 'title_typography',
				'selector' => '{{WRAPPER}} .hx-hero__title',
				'global'   => [
					'default' => Global_Typography::TYPOGRAPHY_TEXT,
				],
			]
		);

		$this->add_control(
			'title_css',
			[
				'label'       => esc_html__( 'CSS Classes', 'hellix-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'default'     => '',
				'description' => esc_html__( 'Applied to testimonial content', 'hellix-elementor' ),

			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'section_sub_title_style',
			[
				'label' => esc_html__( 'Sub Title', 'hellix-elementor' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'sub_title_color',
			[
				'label'     => esc_html__( 'Color', 'hellix-elementor' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .hx-hero__sub_title' => 'color: {{VALUE}}',
				],
				'default'   => '#FFFFFF',
				'global'    => [
					'default' => Global_Colors::COLOR_TEXT,
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'     => 'sub_title_typography',
				'selector' => '{{WRAPPER}} .hx-hero__sub_title',
				'global'   => [
					'default' => Global_Typography::TYPOGRAPHY_TEXT,
				],
			]
		);

		$this->add_control(
			'sub_title_css',
			[
				'label'       => esc_html__( 'CSS Classes', 'hellix-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'default'     => '',
				'description' => esc_html__( 'Applied to testimonial content', 'hellix-elementor' ),

			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'section_description_style',
			[
				'label' => esc_html__( 'Description', 'hellix-elementor' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'desc_title_color',
			[
				'label'     => esc_html__( 'Color', 'hellix-elementor' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .hx-hero__desc_title' => 'color: {{VALUE}}',
				],
				'global'    => [
					'default' => Global_Colors::COLOR_TEXT,
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'     => 'desc_title_typography',
				'selector' => '{{WRAPPER}} .hx-hero__desc_title',
				'global'   => [
					'default' => Global_Typography::TYPOGRAPHY_TEXT,
				],
			]
		);

		$this->add_control(
			'desc_css',
			[
				'label'       => esc_html__( 'CSS Classes', 'hellix-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'default'     => '',
				'description' => esc_html__( 'Applied to description content', 'hellix-elementor' ),

			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'section_pagination_style',
			[
				'label'     => esc_html__( 'Pagination', 'hellix-elementor' ),
				'tab'       => Controls_Manager::TAB_STYLE,
				'condition' => [
					'_skin!' => [ 'hero-caorusel-7', 'hero-caorusel-10' ],
				],
			]
		);

		$this->add_control(
			'pagination_label',
			[
				'label'     => esc_html__( 'Next Text', 'hellix-elementor' ),
				'type'      => Controls_Manager::TEXT,
				'default'   => esc_html__( 'NEXT PROJECT', 'hellix-elementor' ),
				'condition' => [
					'_skin' => [ 'hero-caorusel-4' ],
				],

			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'      => 'pagination_label_typography',
				'selector'  => '{{WRAPPER}} .hx-hero__pagination_label_color',
				'global'    => [
					'default' => Global_Typography::TYPOGRAPHY_TEXT,
				],
				'condition' => [
					'_skin' => [ 'hero-caorusel-4' ],
				],
			]
		);

		$this->add_control(
			'pagination_label_color',
			[
				'label'       => esc_html__( 'Label Color', 'hellix-elementor' ),
				'type'        => Controls_Manager::COLOR,
				'selectors'   => [
					'{{WRAPPER}} .hx-hero__pagination_label_color' => 'color: {{VALUE}}',
				],
				'description' => esc_html__( 'Applied to pagination label', 'hellix-elementor' ),
				'global'      => [
					'default' => Global_Colors::COLOR_TEXT,
				],
				'condition'   => [
					'_skin' => [ 'hero-caorusel-4' ],
				],
				'separator'   => 'after',
			]
		);

		$this->add_control(
			'pagination_title_color',
			[
				'label'     => esc_html__( 'Color', 'hellix-elementor' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .mainSlider.-type-2 .mainSlider-nav .-prev::after' => 'background-color: {{VALUE}}',
					'{{WRAPPER}} .mainSlider.-type-2 .mainSlider-nav .-next::before' => 'background-color: {{VALUE}}',
					'{{WRAPPER}} .pagination_color__title' => 'color: {{VALUE}} !important;',
					'{{WRAPPER}} .masthead-pagination__line' => 'background-color: {{VALUE}}',
					'{{WRAPPER}} .mainSlider.-type-2 .mainSlider-pagination .pagination__item' => 'color: {{VALUE}}',
					'{{WRAPPER}} .mainSlider.-type-2 .mainSlider-pagination .pagination__item::after' => 'background-color: {{VALUE}}',
					'{{WRAPPER}} .mainSlider.-type-9 .pagination__line > span' => 'background-color: {{VALUE}}',
					'{{WRAPPER}} .js-all'                  => 'color: {{VALUE}}',
				],
				'global'    => [
					'default' => Global_Colors::COLOR_TEXT,
				],
				'condition' => [
					'_skin!' => [ 'hero-caorusel-7', 'hero-caorusel-10' ],
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'      => 'pagination_title_typography',
				'selector'  => '{{WRAPPER}} .pagination_color__title',
				'global'    => [
					'default' => Global_Typography::TYPOGRAPHY_TEXT,
				],
				'condition' => [
					'_skin' => [ 'hero-caorusel-1', 'hero-caorusel-4', 'hero-caorusel-2' ],
				],
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'section_style',
			[
				'label'     => esc_html__( 'Button', 'hellix-elementor' ),
				'tab'       => Controls_Manager::TAB_STYLE,
				'condition' => [
					'_skin!' => [ 'hero-caorusel-6' ],
				],
			]
		);

		$this->add_control(
			'button_type',
			[
				'label'     => esc_html__( 'Type', 'hellix-elementor' ),
				'type'      => Controls_Manager::SELECT,
				'default'   => 'dark',
				'options'   => [
					'default'   => esc_html__( 'Default', 'hellix-elementor' ),
					'simple'    => esc_html__( 'Simple', 'hellix-elementor' ),
					'white'     => esc_html__( 'White', 'hellix-elementor' ),
					'dark'      => esc_html__( 'Dark', 'hellix-elementor' ),
					'secondary' => esc_html__( 'Secondary', 'hellix-elementor' ),
					'accent'    => esc_html__( 'Accent', 'hellix-elementor' ),
					'grey'      => esc_html__( 'Grey', 'hellix-elementor' ),
				],
				'condition' => [
					'_skin!' => [ 'hero-caorusel-6' ],
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'     => 'btn_typography',
				'global'   => [
					'default' => Global_Typography::TYPOGRAPHY_ACCENT,
				],
				'selector' => '{{WRAPPER}} .masthead__button',
				'{{WRAPPER}} .mainSlider__button !important;',
				'{{WRAPPER}} .button__text_color',
			]
		);

		$this->add_control(
			'button_text_color',
			[
				'label'     => esc_html__( 'Text Color', 'hellix-elementor' ),
				'type'      => Controls_Manager::COLOR,
				'default'   => '#ffffff',
				'selectors' => [
					'{{WRAPPER}} .button__text_color' => 'fill: {{VALUE}}; color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'button_bg_color',
			[
				'label'     => esc_html__( 'Background Color', 'hellix-elementor' ),
				'type'      => Controls_Manager::COLOR,
				'default'   => '',
				'selectors' => [
					'{{WRAPPER}} .masthead__button' => 'background-color:{{VALUE}} !important;',
					'{{WRAPPER}} .button'           => 'background-color:{{VALUE}} !important;',
					'{{WRAPPER}} .button-color'     => 'background-color:{{VALUE}} !important;',
				],
				'condition' => [
					'_skin!' => [ 'hero-caorusel-1', 'hero-caorusel-4', 'hero-caorusel-9' ],
				],
			]
		);

		$this->end_controls_section();
	}

	/**
	 * Add repeater controls
	 *
	 * @param Repeater $repeater Add controls to this repeater.
	 */
	protected function add_repeater_controls( Repeater $repeater ) {

		$repeater->add_control(
			'title',
			[
				'label' => esc_html__( 'Title', 'hellix-elementor' ),
				'type'  => Controls_Manager::TEXT,
			]
		);

		$repeater->add_control(
			'sub_title',
			[
				'label' => esc_html__( 'Sub Title', 'hellix-elementor' ),
				'type'  => Controls_Manager::TEXT,
			]
		);

		$repeater->add_control(
			'description',
			[
				'label' => esc_html__( 'Description', 'hellix-elementor' ),
				'type'  => Controls_Manager::TEXTAREA,
			]
		);

		$repeater->add_control(
			'image',
			[
				'label'   => __( 'Image', 'hellix-elementor' ),
				'type'    => Controls_Manager::MEDIA,
				'default' => [
					'url' => Utils::get_placeholder_image_src(),
				],
			]
		);

		$repeater->add_group_control(
			Group_Control_Image_Size::get_type(),
			[
				'name'    => 'image_size', // Usage: `{name}_size` and `{name}_custom_dimension`, in this case `thumbnail_size` and `thumbnail_custom_dimension`.
				'default' => 'thumbanil',
			]
		);

		$repeater->add_control(
			'btn_text',
			[
				'label' => esc_html__( 'Button Text', 'hellix-elementor' ),
				'type'  => Controls_Manager::TEXT,
			]
		);

		$repeater->add_control(
			'btn_link',
			[
				'label'       => esc_html__( 'Button Link', 'hellix-elementor' ),
				'type'        => Controls_Manager::URL,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => esc_html__( 'https://your-link.com', 'hellix-elementor' ),
				'default'     => [
					'url' => '#',
				],
			]
		);
	}

	/**
	 * Get the default values for the repeater controls
	 */
	protected function get_repeater_defaults() {
		$placeholder_image_src = Utils::get_placeholder_image_src();

		return [
			[
				'title'    => esc_html__( 'Imperial Property Group Agent', 'hellix-elementor' ),
				'btn_text' => esc_html__( 'VIEW PROJECT', 'hellix-elementor' ),
				'image'    => [
					'url' => $placeholder_image_src,
				],
			],
			[

				'title'    => esc_html__( 'Imperial Property Group Agent', 'hellix-elementor' ),
				'btn_text' => esc_html__( 'VIEW PROJECT', 'hellix-elementor' ),
				'image'    => [
					'url' => $placeholder_image_src,
				],

			],
			[

				'title'    => esc_html__( 'Imperial Property Group Agent', 'hellix-elementor' ),
				'btn_text' => esc_html__( 'VIEW PROJECT', 'hellix-elementor' ),
				'image'    => [
					'url' => $placeholder_image_src,
				],

			],
		];
	}

}

