<?php
namespace HellixElementor\Modules\Carousel\Widgets;

use Elementor\Controls_Manager;
use Elementor\Core\Kits\Documents\Tabs\Global_Colors;
use Elementor\Core\Kits\Documents\Tabs\Global_Typography;
use Elementor\Group_Control_Typography;
use HellixElementor\Modules\Carousel\Skins;
use Elementor\Repeater;
use Elementor\Utils;
use Elementor\Icons_Manager;
use Elementor\Plugin;
use HellixElementor\Core\Utils as HXUtils;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * Team Member Carousel Hellix Elementor Widget.
 */
class Team_Member_Carousel extends Base {


	/**
	 * Get the name of the widget.
	 *
	 * @return string
	 */
	public function get_name() {
		return 'hx-team-member-carousel';
	}

	/**
	 * Get the title of the widget.
	 *
	 * @return string
	 */
	public function get_title() {
		return esc_html__( 'Team Member Carousel', 'hellix-elementor' );
	}

	/**
	 * Get the icon for the widget.
	 *
	 * @return string
	 */
	public function get_icon() {
		return 'eicon-posts-carousel';
	}

	/**
	 * Get the keywords associated with the widget.
	 *
	 * @return array
	 */
	public function get_keywords() {
		return [ 'team', 'member', 'carousel', 'image' ];
	}

	/**
	 * Get the group for this widget.
	 *
	 * @return string
	 */
	public function get_group_name() {
		return 'carousel';
	}

	/**
	 * Register the Skins with the widget.
	 *
	 * @return void
	 */
	protected function register_skins() {
		$this->add_skin( new Skins\Team_Member_Style_1( $this ) );
	}

	/**
	 * Register controls for this widget.
	 */
	protected function register_controls() {
		parent::register_controls();
		$this->start_injection(
			[
				'at' => 'before',
				'of' => 'section_navigation',
			]
		);

		$this->start_controls_section(
			'section_content_style',
			[
				'label' => esc_html__( 'Styles', 'hellix-elementor' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'heading_designation_style',
			[
				'label' => esc_html__( 'Designation', 'hellix-elementor' ),
				'type'  => Controls_Manager::HEADING,
			]
		);

		$this->add_control(
			'content_color',
			[
				'label'     => esc_html__( 'Text Color', 'hellix-elementor' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .hx-team-member__designation' => 'color: {{VALUE}}',
				],
				'global'    => [
					'default' => Global_Colors::COLOR_TEXT,
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'     => 'content_typography',
				'selector' => '{{WRAPPER}} .hx-team-member__designation',
				'global'   => [
					'default' => Global_Typography::TYPOGRAPHY_TEXT,
				],
			]
		);

		$this->add_control(
			'designation_css',
			[
				'label'       => esc_html__( 'CSS Classes', 'hellix-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'description' => esc_html__( 'Applied to designation text', 'hellix-elementor' ),

			]
		);

		$this->add_control(
			'heading_name_style',
			[
				'label'     => esc_html__( 'Name', 'hellix-elementor' ),
				'type'      => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);

		$this->add_control(
			'name_color',
			[
				'label'     => esc_html__( 'Name Color', 'hellix-elementor' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .hx-team-member__name' => 'color: {{VALUE}} !important;',
				],
				'global'    => [
					'default' => Global_Colors::COLOR_PRIMARY,
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'     => 'title_typography',
				'selector' => '{{WRAPPER}} .hx-team-member__name',
				'global'   => [
					'default' => Global_Typography::TYPOGRAPHY_SECONDARY,
				],
			]
		);

		$this->add_control(
			'name_css',
			[
				'label'       => esc_html__( 'CSS Classes', 'hellix-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'description' => esc_html__( 'Applied to team member name', 'hellix-elementor' ),
				'default'     => esc_html( ' text-white', 'hellix-elementor' ),
			]
		);

		$this->add_control(
			'social_icon_color',
			[
				'label'     => esc_html__( 'Social Icon Color', 'hellix-elementor' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .hx-team-member_social_icon' => 'color: {{VALUE}} !important;',
				],
				'global'    => [
					'default' => Global_Colors::COLOR_PRIMARY,
				],
			]
		);

		$this->add_control(
			'image_style',
			[
				'label'     => esc_html__( 'Image', 'hellix-elementor' ),
				'type'      => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);

		$this->add_control(
			'image_ratio',
			[
				'label'       => esc_html__( 'Image Ratio', 'hellix-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'description' => esc_html__( 'Applied to image ratio', 'hellix-elementor' ),
				'default'     => esc_html( '3:4', 'hellix-elementor' ),
			]
		);

		$this->end_controls_section();

		$this->end_injection();
		$this->remove_control( 'section_navigation' );
	}

	/**
	 * Add repeater controls
	 *
	 * @param Repeater $repeater Add controls to this repeater.
	 */
	protected function add_repeater_controls( Repeater $repeater ) {

		$repeater->add_control(
			'name',
			[
				'label'   => esc_html__( 'Name', 'hellix-elementor' ),
				'type'    => Controls_Manager::TEXT,
				'default' => esc_html__( 'Albert Flores', 'hellix-elementor' ),
			]
		);

		$repeater->add_control(
			'designation',
			[
				'label'   => esc_html__( 'Designation', 'hellix-elementor' ),
				'type'    => Controls_Manager::TEXT,
				'default' => esc_html__( 'Technology Officer', 'hellix-elementor' ),
			]
		);

		$repeater->add_control(
			'image',
			[
				'label'   => __( 'Image', 'hellix-elementor' ),
				'type'    => Controls_Manager::MEDIA,
				'default' => [
					'url' => Utils::get_placeholder_image_src(),
				],
			]
		);

		$repeater->add_control(
			'social_icon',
			[
				'type'      => Controls_Manager::SWITCHER,
				'label'     => esc_html__( 'Need Social Icon', 'hellix-elementor' ),
				'default'   => 'no',
				'label_off' => esc_html__( 'Hide', 'hellix-elementor' ),
				'label_on'  => esc_html__( 'Show', 'hellix-elementor' ),
			]
		);

		$repeater->add_control(
			'icon_1',
			[
				'label'            => esc_html__( 'Icon 1', 'hellix-elementor' ),
				'type'             => Controls_Manager::ICONS,
				'fa4compatibility' => 'icon',
				'condition'        => [ 'social_icon' => 'yes' ],
			]
		);

		$repeater->add_control(
			'icon_link_1',
			[
				'label'       => esc_html__( 'Icon Link 1', 'hellix-elementor' ),
				'type'        => Controls_Manager::URL,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => esc_html__( 'https://your-link.com', 'hellix-elementor' ),
				'default'     => [
					'url' => '#',
				],
				'condition'   => [ 'social_icon' => 'yes' ],
			]
		);

		$repeater->add_control(
			'icon_2',
			[
				'label'            => esc_html__( 'Icon 2', 'hellix-elementor' ),
				'type'             => Controls_Manager::ICONS,
				'fa4compatibility' => 'icon',
				'condition'        => [ 'social_icon' => 'yes' ],
			]
		);

		$repeater->add_control(
			'icon_link_2',
			[
				'label'       => esc_html__( 'Icon Link 2', 'hellix-elementor' ),
				'type'        => Controls_Manager::URL,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => esc_html__( 'https://your-link.com', 'hellix-elementor' ),
				'default'     => [
					'url' => '#',
				],
				'condition'   => [ 'social_icon' => 'yes' ],
			]
		);

		$repeater->add_control(
			'icon_3',
			[
				'label'            => esc_html__( 'Icon 3', 'hellix-elementor' ),
				'type'             => Controls_Manager::ICONS,
				'fa4compatibility' => 'icon',
				'condition'        => [ 'social_icon' => 'yes' ],
			]
		);

		$repeater->add_control(
			'icon_link_3',
			[
				'label'       => esc_html__( 'Icon Link 3', 'hellix-elementor' ),
				'type'        => Controls_Manager::URL,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => esc_html__( 'https://your-link.com', 'hellix-elementor' ),
				'default'     => [
					'url' => '#',
				],
				'condition'   => [ 'social_icon' => 'yes' ],
			]
		);

		$repeater->add_control(
			'icon_4',
			[
				'label'            => esc_html__( 'Icon 4', 'hellix-elementor' ),
				'type'             => Controls_Manager::ICONS,
				'fa4compatibility' => 'icon',
				'condition'        => [ 'social_icon' => 'yes' ],
			]
		);

		$repeater->add_control(
			'icon_link_4',
			[
				'label'       => esc_html__( 'Icon Link 4', 'hellix-elementor' ),
				'type'        => Controls_Manager::URL,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => esc_html__( 'https://your-link.com', 'hellix-elementor' ),
				'default'     => [
					'url' => '#',
				],
				'condition'   => [ 'social_icon' => 'yes' ],
			]
		);

	}

	/**
	 * Get the default values for the repeater controls
	 */
	protected function get_repeater_defaults() {
		$placeholder_image_src = Utils::get_placeholder_image_src();

		return [
			[
				'name'        => esc_html__( 'Albert Flores', 'hellix-elementor' ),
				'designation' => esc_html__( 'INTERIOR DESIGNER', 'hellix-elementor' ),
			],
			[
				'name'        => esc_html__( 'Jenny Wilson', 'hellix-elementor' ),
				'designation' => esc_html__( 'Chief Financial Officer', 'hellix-elementor' ),
			],
			[
				'name'        => esc_html__( 'Devon Lane', 'hellix-elementor' ),
				'designation' => esc_html__( 'President & CEO', 'hellix-elementor' ),
			],
		];
	}

	/**
	 * Render Name.
	 *
	 * @param int   $index index.
	 * @param array $settings settings.
	 * @param array $slide slide.
	 * @return void
	 */
	public function render_name( $index, $settings, $slide ) {

		$this->add_render_attribute( 'name_css_' . $index, 'class', [ 'hx-team-member__name', 'team__title' ] );

		if ( ! empty( $settings['name_css'] ) ) {
			$this->add_render_attribute( 'name_css_' . $index, 'class', $settings['name_css'] );
		}

		if ( ! empty( $slide['name'] ) ) : ?>
				<<?php echo esc_html( $settings['title_tag'] ); ?>  <?php $this->print_render_attribute_string( 'name_css_' . $index ); ?>>
					<?php echo esc_html( $slide['name'] ); ?> 
				</<?php echo esc_html( $settings['title_tag'] ); ?>>
			<?php
		endif;
	}

	/**
	 * Render Designation.
	 *
	 * @param int    $index index.
	 * @param array  $settings settings.
	 * @param array  $slide slide.
	 * @param string $tag tag.
	 * @return void
	 */
	public function render_designation( $index, $settings, $slide, $tag = 'div' ) {

		$this->add_render_attribute( 'des_css_' . $index, 'class', [ 'hx-team-member__designation', 'team__info' ] );

		if ( ! empty( $settings['designation_css'] ) ) {
			$this->add_render_attribute( 'des_css_' . $index, 'class', $settings['designation_css'] );
		}

		?>
		<<?php echo esc_html( $tag ); ?> <?php $this->print_render_attribute_string( 'des_css_' . $index ); ?>>
			<?php echo esc_html( $slide['designation'] ); ?>
		</<?php echo esc_html( $tag ); ?>>
		<?php
	}

	/**
	 * Slick Settings.
	 *
	 * @param array $settings settings.
	 * @return string
	 */
	public function get_slick_carousel_options( array $settings = null ) {

		$column      = ! empty( $settings['slides_per_view_mobile'] ) ? 'sm-' . intval( $settings['slides_per_view_mobile'] ) : 'sm-2';
		$column_md   = ! empty( $settings['slides_per_view_tablet'] ) ? 'md-' . intval( $settings['slides_per_view_tablet'] ) : 'md-2';
		$column_lg   = 'lg-3';
		$column_base = ! empty( $settings['slides_per_view'] ) ? 'base-' . intval( $settings['slides_per_view'] ) : 'base-4';

		$default_carousel_args = $column_base . ' ' . $column_lg . ' ' . $column_md . ' ' . $column;

		return $default_carousel_args;
	}

	/**
	 * Print Slider.
	 *
	 * @param array $settings settings.
	 * @return void
	 */
	public function print_slider( array $settings = null ) {

		if ( null === $settings ) {
			$settings = $this->get_settings_for_display();
		}

		$slider_class = array( 'container_class' => 'sectionSlider overflow-hidden sm:px-16 js-sectionSlider' );
		$gutter       = ! empty( $settings['gutter'] ) ? intval( $settings['gutter']['size'] ) : 30;

		$this->add_render_attribute(
			'slider',
			array(
				'class'           => $slider_class,
				'data-slider-col' => $this->get_slick_carousel_options( $settings ),
				'data-gap'        => $gutter,
			)
		);
		?>
		
		<div class="row layout-pt-sm m-0">
			<div <?php $this->print_render_attribute_string( 'slider' ); ?> data-pagination>

				<div class="swiper-wrapper">
					<?php
					foreach ( $settings['slides'] as $slide ) :
						$this->print_slide( $slide, $settings, 'image-slide-' . $slide['_id'] );
					endforeach;
					?>
				</div>
				<?php if ( 'yes' === $settings['show_arrows'] ) { ?>
					<?php $this->render_navigation(); ?>
				<?php } ?>
				<?php
				if ( 'yes' === $settings['show_dots'] ) {
					?>
					<div class="pagination -slider mt-48 js-pagination"></div>
				<?php } ?>
			</div>
		</div>
		<?php
	}

	/**
	 * Render Navigation.
	 *
	 * @return void
	 */
	public function render_navigation() {
		?>
		<div class="nav -slider lg:d-none">
			<div class="nav__item -left js-prev">
				<i class="icon icon-left-arrow"></i>
			</div>

			<div class="nav__item -right js-next">
				<i class="icon icon-right-arrow"></i>
			</div>
		</div>
		<?php
	}

	 /**
	  * Render Social Icons.
	  *
	  * @param array $slide slide.
	  * @return void
	  */
	public function render_social_icons( $slide ) {
		?>
		<div class="team__socials">
			<?php
			for ( $i = 1; $i <= 4; $i++ ) {
				if ( ! empty( $slide[ 'icon_' . $i ]['value'] ) ) {
					$this->add_render_attribute(
						'social_icons_attr-' . $slide['_id'] . $i,
						array(
							'data-barba' => '',
							'class'      => 'hx-team-member_social_icon text-white',
							'href'       => $slide[ 'icon_link_' . $i ]['url'],
						)
					);
					?>
					<a <?php $this->print_render_attribute_string( 'social_icons_attr-' . $slide['_id'] . $i ); ?>>
						<?php
						Icons_Manager::render_icon( $slide[ 'icon_' . $i ], [ 'aria-hidden' => 'true' ] );
						?>
					</a>
					<?php
				}
			}
			?>
		</div>
		<?php
	}

	/**
	 * Print Slide.
	 *
	 * @param array $slide slide.
	 * @param array $settings settings.
	 * @param int   $index index.
	 * @return void
	 */
	public function print_slide( array $slide, array $settings, $index ) {
		$link = $slide['image']['url'];
		$img = $settings['image_ratio'];
		?>

		<div class="swiper-slide">
			<div class="team -hover">
				<div data-anim="img-right cover-black" class="team__image">
					<div>
						<?php echo wp_kses_post( HXUtils::render_bg_image( $link, '', $img ) ); ?>
					</div>
				</div>
				<div class="team__content">
					<?php
					if ( 'yes' === $slide['social_icon'] ) {
						$this->render_social_icons( $slide );
					}
					?>

					<div class="md:d-none">
						<?php $this->render_designation( $index, $settings, $slide ); ?>
						<?php $this->render_name( $index, $settings, $slide ); ?>
					</div>
				</div>
			</div>
		</div>
		<?php
	}

	/**
	 * Render.
	 *
	 * @return void
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();
		$this->print_slider( $settings );
		$this->render_script();
	}

}
