<?php

namespace HellixElementor\Modules\IconBox\Skins;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

use Elementor;
use Elementor\Icons_Manager;
use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Skin_Base;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Background;
use HellixElementor\Plugin;
use Elementor\Core\Kits\Documents\Tabs\Global_Colors;
use Elementor\Core\Kits\Documents\Tabs\Global_Typography;
use HellixElementor\Core\Utils as HXUtils;
use Elementor\Skin_Base as Elementor_Skin_Base;

/**
 * Skin Icon Box - Skin_Icon_Box_Style_2
 */
class Skin_Icon_Box_Style_2 extends Skin_Base {

	/**
	 * Constructor.
	 *
	 * @param Elementor\Widget_Base $parent The widget settings.
	 * @return void
	 */
	public function __construct( Elementor\Widget_Base $parent ) {
		parent::__construct( $parent );
	}

	/**
	 * Get the id of the skin.
	 *
	 * @return string
	 */
	public function get_id() {
		return 'hellix-style-2';
	}

	/**
	 * Get the title of the skin.
	 *
	 * @return string
	 */
	public function get_title() {
		return esc_html__( 'Hellix style 2', 'hellix-elementor' );
	}

	/**
	 * Register controls actions.
	 */
	protected function _register_controls_actions() {

		add_filter( 'elementor/widget/print_template', array( $this, 'skin_print_template' ), 10, 2 );
	}

	/**
	 * Render the skin output.
	 *
	 * @return void
	 */
	public function render() {

		$widget       = $this->parent;
		$settings     = $widget->get_settings_for_display();
		$icon_wrapper = $settings['icon_wraper_css'];
		$rounded_size = 'size-' . $settings['rounded_size'];
		$number_css   = $settings['number_css'];

		if ( ! isset( $settings['icon'] ) && ! Icons_Manager::is_migration_allowed() ) {

			$settings['icon'] = '';
		}

		$has_icon = ! empty( $settings['icon'] );

		if ( ! $has_icon && ! empty( $settings['selected_icon']['value'] ) ) {
			$has_icon = true;
		}
		$div_wrapper_css = 'background-num -hover text-center';
		$div_wrapper_css = ! empty( $number_css ) ? $div_wrapper_css . ' ' . $number_css : $div_wrapper_css;

		$widget->add_render_attribute(
			'div-wrapper',
			[
				'data-anim' => 'slide-up delay-1t',
				'class'     => $div_wrapper_css,
			]
		);
		$icon_wrapper_class = $rounded_size . ' rounded-full d-flex shadow-light  justify-content-center align-items-center';
		$icon_wrapper_class = ! empty( $icon_wrapper ) ? $icon_wrapper_class . ' ' . $icon_wrapper : $icon_wrapper_class;
		$widget->add_render_attribute( 'icon-wrapper__css', 'class', $icon_wrapper_class );
		?>
		<div <?php $widget->print_render_attribute_string( 'div-wrapper' ); ?>>
			<div class="background-num__wrap">
				<?php if ( ! empty( $settings['bg_number'] ) ) { ?>
				<div class="background-num__num number__color">
					<?php echo esc_html( $settings['bg_number'] ); ?> 
				</div>
			<?php } ?>
			</div>
			<?php if ( $has_icon ) : ?>
				<div class="d-flex justify-content-center background-num__front">
					<div <?php $widget->print_render_attribute_string( 'icon-wrapper__css' ); ?>>
						<?php $this->render_icon( $settings ); ?>
					</div>
				</div>
			<?php endif; ?>

			<?php
			if ( ! empty( $settings['title_text'] ) ) {
					$this->render_title( $settings );
			}
			?>

			<?php
			if ( ! empty( $settings['description_text'] ) ) {
					$this->render_description( $settings );
			}
			?>
		</div> 
		<?php
	}

	/**
	 * Render title.
	 *
	 * @param array $settings The widget settings.
	 */
	public function render_title( $settings ) {

		$widget    = $this->parent;
		$title_css = $settings['title_css'];
		$tag       = $settings['title_size'];
		$widget->add_render_attribute( 'title', 'class', [ ' elementor-icon-box-title' ] );

		if ( ! empty( $settings['title_css'] ) ) {
			$widget->add_render_attribute( 'title', 'class', $title_css );
		}
		?>
		<<?php echo esc_html( $tag ); ?> <?php $widget->print_render_attribute_string( 'title' ); ?>>
			<?php echo esc_html( $settings['title_text'] ); ?>
		</<?php echo esc_html( $tag ); ?> > 
		<?php
	}

	/**
	 * Render Icon.
	 *
	 * @param array $settings The widget settings.
	 */
	public function render_icon( $settings ) {

		$widget       = $this->parent;
		$icon_css     = $settings['icon_css'];
		$rounded_size = 'text-' . $settings['rounded_size'];

		Icons_Manager::render_icon(
			$settings['selected_icon'],
			[
				'aria-hidden' => 'true',
				'class'       => [ 'elementor-icon elementor-icon-box icon ' . $rounded_size, $icon_css ],
			]
		);
	}

	/**
	 * Render description.
	 *
	 * @param array $settings The widget settings.
	 */
	public function render_description( $settings ) {

		$widget   = $this->parent;
		$desc_css = $settings['description_css'];

		$widget->add_render_attribute( 'description_text', 'class', [ 'elementor-icon-box-description' ] );

		if ( ! empty( $desc_css ) ) {
			$widget->add_render_attribute( 'description_text', 'class', $desc_css );
		}
		?>
		<p <?php $widget->print_render_attribute_string( 'description_text' ); ?>>
			<?php echo wp_kses_post( $settings['description_text'] ); ?>
		</p> 
		<?php
	}

	/**
	 * Print Template.
	 *
	 * @param string                $content The skin output string.
	 * @param Elementor\Widget_Base $widget The widget.
	 *
	 * @return string
	 */
	public function skin_print_template( $content, $widget ) {
		if ( 'icon-box' == $widget->get_name() ) {
			return '';
		}
		return $content;
	}
}
