<?php

namespace HellixElementor\Modules\IconBox\Skins;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

use Elementor;
use Elementor\Icons_Manager;
use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Skin_Base;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Background;
use HellixElementor\Plugin;
use Elementor\Core\Kits\Documents\Tabs\Global_Colors;
use Elementor\Core\Kits\Documents\Tabs\Global_Typography;
use HellixElementor\Core\Utils as HXUtils;
use Elementor\Skin_Base as Elementor_Skin_Base;

/**
 * Skin Icon Box - Skin_Icon_Box_Style_3
 */
class Skin_Icon_Box_Style_3 extends Skin_Base {

	/**
	 * Constructor.
	 *
	 * @param Elementor\Widget_Base $parent The widget settings.
	 * @return void
	 */
	public function __construct( Elementor\Widget_Base $parent ) {
		parent::__construct( $parent );
	}

	/**
	 * Get the id of the skin.
	 *
	 * @return string
	 */
	public function get_id() {
		return 'hellix-style-3';
	}

	/**
	 * Get the title of the skin.
	 *
	 * @return string
	 */
	public function get_title() {
		return esc_html__( 'Hellix style 3', 'hellix-elementor' );
	}

	/**
	 * Register controls actions.
	 */
	protected function _register_controls_actions() {

		add_filter( 'elementor/widget/print_template', array( $this, 'skin_print_template' ), 10, 2 );
		add_action( 'elementor/element/icon-box/section_icon/before_section_end', [ $this, 'register_content_icon_controls' ], 10 );

	}

	/**
	 * Register Content Icon controls.
	 *
	 * @param Elementor\Widget_Base $widget The widget settings.
	 */
	public function register_content_icon_controls( $widget ) {

		$widget->add_control(
			'border_need',
			[
				'label'     => esc_html__( 'Need Border ?', 'hellix-elementor' ),
				'type'      => Controls_Manager::SWITCHER,
				'default'   => 'yes',
				'label_off' => esc_html__( 'Hide', 'hellix-elementor' ),
				'label_on'  => esc_html__( 'Show', 'hellix-elementor' ),
				'condition' => [ '_skin' => [ 'hellix-style-3' ] ],

			]
		);
	}

	/**
	 * Render the skin output.
	 *
	 * @return void
	 */
	public function render() {

		$widget       = $this->parent;
		$settings     = $widget->get_settings_for_display();
		$icon_wrapper = $settings['icon_wraper_css'];
		$rounded_size = 'size-' . $settings['rounded_size'];

		if ( ! isset( $settings['icon'] ) && ! Icons_Manager::is_migration_allowed() ) {

			$settings['icon'] = '';
		}

		$has_icon = ! empty( $settings['icon'] );

		if ( ! $has_icon && ! empty( $settings['selected_icon']['value'] ) ) {
			$has_icon = true;
		}

		$hover = '';

		if ( 'yes' === $settings['border_need'] ) {
			?>       
		<div data-anim="slide-up" class="py-40 px-64 sm:px-48 d-flex flex-column align-items-center text-center border-dark bottom-line -accent">
			<?php
		} else {
			$hover = 'service__icon';
			?>
		<div class="service -icon-hover">
	   <?php } ?>
			<div class="d-flex">
				<?php
				$icon_hover_wrap = $rounded_size . ' bg-beige-light rounded-full d-flex align-items-center justify-content-center';
				$icon_hover_wrap = ! empty( $hover ) ? $icon_hover_wrap . ' ' . $hover : $icon_hover_wrap;
				$icon_hover_wrap = ! empty( $icon_wrapper ) ? $icon_hover_wrap . ' ' . $icon_wrapper : $icon_hover_wrap;
				$widget->add_render_attribute( 'service-icon-wrapper-css', 'class', $icon_hover_wrap );
				?>
				<div <?php $widget->print_render_attribute_string( 'service-icon-wrapper-css' ); ?>>
					<?php if ( $has_icon ) : ?>
						<?php $this->render_icon( $settings ); ?>
					<?php endif; ?>
				</div>
			</div>
			<?php
			if ( ! empty( $settings['title_text'] ) ) {
					$this->render_title( $settings );
			}
			?>

			<?php
			if ( ! empty( $settings['description_text'] ) ) {
					$this->render_description( $settings );
			}
			?>
			<?php
			if ( ! empty( $settings['btn_txt'] ) ) {
					$this->render_button( $settings );
			}
			?>
		</div>
		<?php
	}

	/**
	 * Render button.
	 *
	 * @param array $settings The widget settings.
	 */
	public function render_button( $settings ) {
		$widget   = $this->parent;
		$btn_txt  = $settings['btn_txt'];
		$btn_size = '';
		if ( 'simple' !== $settings['button_type'] ) {
			$btn_size = '-md';
		}
		$class_btn = 'button__text_color button text-black mt-24 ' . $btn_size . ' -' . $settings['button_type'];

		$widget->add_render_attribute( 'button', 'class', $class_btn );
		if ( ! empty( $settings['link']['url'] ) ) {
			$widget->add_link_attributes( 'button', $settings['link'] );
		}

		?>
		<a <?php $widget->print_render_attribute_string( 'button' ); ?>> 
			<?php echo esc_html( $btn_txt ); ?> 
		</a>
		<?php
	}

	/**
	 * Render title.
	 *
	 * @param array $settings The widget settings.
	 */
	public function render_title( $settings ) {

		$widget    = $this->parent;
		$title_css = $settings['title_css'];
		$tag       = $settings['title_size'];
		$widget->add_render_attribute( 'title', 'class', [ '  elementor-icon-box-title' ] );

		if ( ! empty( $settings['title_css'] ) ) {
			$widget->add_render_attribute( 'title', 'class', $title_css );
		}
		?>
	   <<?php echo esc_html( $tag ); ?> <?php $widget->print_render_attribute_string( 'title' ); ?>>
			<?php echo esc_html( $settings['title_text'] ); ?>
		</<?php echo esc_html( $tag ); ?> > 
		<?php
	}

	/**
	 * Render description.
	 *
	 * @param array $settings The widget settings.
	 */
	public function render_description( $settings ) {

		$widget   = $this->parent;
		$desc_css = $settings['description_css'];

		$widget->add_render_attribute( 'description_text', 'class', [ 'elementor-icon-box-description' ] );

		if ( ! empty( $desc_css ) ) {
			$widget->add_render_attribute( 'description_text', 'class', $desc_css );
		}
		?>
		<p <?php $widget->print_render_attribute_string( 'description_text' ); ?>>
			<?php echo wp_kses_post( $settings['description_text'] ); ?>
		</p> 
		<?php
	}

	/**
	 * Render Icon.
	 *
	 * @param array $settings The widget settings.
	 */
	public function render_icon( $settings ) {

		$widget       = $this->parent;
		$icon_css     = $settings['icon_css'];
		$rounded_size = 'text-' . $settings['rounded_size'];

		Icons_Manager::render_icon(
			$settings['selected_icon'],
			[
				'aria-hidden' => 'true',
				'class'       => [ 'elementor-icon elementor-icon-box icon text-accent ' . $rounded_size, $icon_css ],
			]
		);
	}

	/**
	 * Print Template.
	 *
	 * @param string                $content The skin output string.
	 * @param Elementor\Widget_Base $widget The widget.
	 *
	 * @return string
	 */
	public function skin_print_template( $content, $widget ) {
		if ( 'icon-box' == $widget->get_name() ) {
			return '';
		}
		return $content;
	}
}
