<?php
namespace HellixElementor\Modules\Posts\Skins;

use Elementor\Controls_Manager;
use Elementor\Core\Kits\Documents\Tabs\Global_Colors;
use Elementor\Core\Kits\Documents\Tabs\Global_Typography;
use Elementor\Group_Control_Css_Filter;
use Elementor\Group_Control_Image_Size;
use Elementor\Group_Control_Typography;
use Elementor\Icons_Manager;
use Elementor\Skin_Base as Elementor_Skin_Base;
use Elementor\Widget_Base;
use Elementor\Utils;
use HellixElementor\Modules\Posts\Traits\Button_Widget_Trait;
use HellixElementor\Modules\Posts\Widgets\Posts_Base;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * The posts skin base.
 */
abstract class Skin_Portfolio_Base extends Elementor_Skin_Base {

	use Button_Widget_Trait;

	/**
	 * Save current permalink to avoid conflict with plugins the filters the permalink during the post render.
	 *
	 * @var string
	 */
	protected $current_permalink;



	/**
	 * The base render class. Just include the render_post inside the skin.
	 */
	public function render() {
		$settings = $this->parent->get_settings_for_display();
		$this->parent->query_posts();

		if ( ! class_exists( 'Hellix_Jetpack_Portfolio' ) ) {
			?><div class="alert -error">
				<div class="alert__content justify-content-center">
					<div class="alert__title text-lg">
						<?php echo esc_html( 'Please enable hellix-extension plugin to view portfolio' ); ?>
					</div>
				</div>
			</div>
			<?php

			return;
		}

		$query = $this->parent->get_query();

		if ( ! $query->found_posts ) {
			?>
			<div class="alert -warning">
				<div class="alert__content justify-content-center">
					<div class="alert__title text-lg">
						<?php echo esc_html( 'No Projects Found' ); ?>
					</div>
				</div>
			</div>
			<?php
			return;
		}

		$this->render_loop_header( $settings );

		// It's the global `wp_query` it self. and the loop was started from the theme.
		if ( $query->in_the_loop ) {
			$this->current_permalink = get_permalink();
			$this->render_post();
		} else {
			while ( $query->have_posts() ) {
				$query->the_post();

				$this->current_permalink = get_permalink();
				$this->render_post();
			}
		}

		wp_reset_postdata();

		$this->render_loop_footer();
		$this->parent->render_script();
	}


	/**
	 * Output the portfolio category filter.
	 */
	protected function portfolio_filters() {
		$portfolio_cats = array();
		$query          = $this->parent->get_query();
		while ( $query->have_posts() ) :
			$query->the_post();
			$portfolio_types = get_the_terms( get_the_ID(), 'jetpack-portfolio-type' );

			if ( ! $portfolio_types || is_wp_error( $portfolio_types ) ) {
				$portfolio_types = array();
			}

			$portfolio_types = array_values( $portfolio_types );

			foreach ( array_keys( $portfolio_types ) as $key ) {
				_make_cat_compat( $portfolio_types[ $key ] );
			}

			foreach ( $portfolio_types as $portfolio_type ) {
				$portfolio_cats[ $portfolio_type->slug ] = $portfolio_type->name;
			}

		endwhile;
		?>
			<div class="col-auto">
				<div class="filter-button-group text-dark fw-500 mt-32">
					<button class="button mr-20 btn-active" data-filter="*">All</button> 
					<?php foreach ( $portfolio_cats as $key => $portfolio_cat ) : ?>
						<button class="button mr-20" data-filter=".<?php echo esc_attr( $key ); ?>" >
								<?php echo esc_html( $portfolio_cat ); ?>
						</button>
					<?php endforeach; ?>
				</div>
			</div>
		<?php
	}

	/**
	 * Output the portfolio category filter.
	 *
	 * @param array $settings The settings instance.
	 */
	protected function portfolio_section_heading( $settings ) {
		?>
		<div class="col-auto">
			<div class="sectionHeading -left-line">
				<span class="sectionHeading__subtitle"><?php echo esc_html( $settings['section_subtitle'] ); ?></span>
				<h2 class="sectionHeading__title"><?php echo esc_html( $settings['section_title'] ); ?></h2>
			</div>
		</div>
		<?php
	}

	/**
	 * Get the container class for the loop.
	 */
	public function get_container_class() {
		return 'elementor-posts--skin-' . $this->get_id();
	}

	/**
	 * Render Loop Header.
	 *
	 * @param string $settings The settings instance.
	 */
	protected function render_loop_header( $settings ) {
		$widget  = $this->parent;
		$padding = '';
		$classes = [
			'masonry',
			'layout-pt-sm',
			'js-masonry',
			'js-masonry-no-filter',
			'elementor-posts-container',
		];

		if ( isset( $settings['column'] ) && ! empty( $settings['column'] ) ) {
			$classes[] .= $settings['column'];
		}
		if ( isset( $settings['gap'] ) && ! empty( $settings['gap'] ) ) {
			$classes[] .= $settings['gap'];
		}

		if ( isset( $settings['padding'] ) && ! empty( $settings['padding'] ) ) {
			$padding = $settings['padding'];
		}

		if ( isset( $settings['heading'] ) && ! empty( $settings['heading'] ) ) {
			$space = 'justify-content-between';
		} else {
			$space = 'justify-content-center';
		}

		$wp_query = $this->parent->get_query();

		$this->parent->add_render_attribute(
			'layout',
			[
				'class' => $classes,
			]
		);

		?>
		<div class="section-filter <?php echo esc_attr( $padding ); ?>">
			<?php
			if ( 'yes' === $settings['container'] ) {
				?>
				<div class="container">
				<?php
			}
			?>
				<div class="row <?php echo esc_attr( $space ); ?>">
					<?php
					if ( 'yes' === $settings['heading'] ) {
						$this->portfolio_section_heading( $settings );
					}
					if ( 'yes' === $settings['filters'] ) {
						$this->portfolio_filters();
					}
					?>
				</div>
			<?php
			if ( 'yes' === $settings['container'] ) {
				?>
				</div>
				<?php
			}
			?>
			<div <?php $widget->print_render_attribute_string( 'layout' ); ?>>
				<div class="masonry__sizer"></div>
		<?php
	}

	/**
	 * Render loop footer.
	 */
	public function render_loop_footer() {
		?>
			</div>
		</div>
		<?php
		$this->parent->hellix_pagination();
	}
}
