<?php
namespace HellixElementor\Modules\Posts\Skins;

use Elementor\Controls_Manager;
use Elementor\Core\Kits\Documents\Tabs\Global_Colors;
use Elementor\Core\Kits\Documents\Tabs\Global_Typography;
use Elementor\Group_Control_Image_Size;
use Elementor\Group_Control_Typography;
use Elementor\Widget_Base;
use Elementor\Skin_Base as Elementor_Skin_Base;
use HellixElementor;
use HellixElementor\Plugin;
use HellixElementor\Core\Utils as HX_Utils;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * The Protfolio Style 1.
 */
class Skin_Portfolio_Style_1 extends Skin_Portfolio_Base {

	/**
	 * Get the name of the widget.
	 *
	 * @return string
	 */
	public function get_id() {
		return 'portfolio-style-1';
	}

	/**
	 * Get the title of the skin.
	 *
	 * @return string
	 */
	public function get_title() {
		return esc_html__( 'Portfolio Style 1', 'hellix-elementor' );
	}

	/**
	 * Register control actions
	 */
	protected function _register_controls_actions() { //phpcs:ignore PSR2.Methods.MethodDeclaration.Underscore
		add_action( 'elementor/element/hx-portfolio/section_layout/after_section_end', [ $this, 'register_style_controls' ] );
	}

	/**
	 * Register market style content controls.
	 *
	 * @param array $widget The widget settings.
	 * @return void
	 */
	public function register_style_controls( $widget ) {

		$this->parent = $widget;

		$this->parent->start_injection(
			[
				'at' => 'after',
				'of' => '_skin',
			]
		);

		$this->add_control(
			'style',
			[
				'label'   => esc_html__( 'Style', 'hellix-elementor' ),
				'type'    => Controls_Manager::SELECT,
				'default' => 'style-v1',
				'options' => [
					'style-v1' => 'Style v1',
					'style-v2' => 'Style v2',
				],
			]
		);

		$this->parent->end_injection();

		$this->parent->start_injection(
			[
				'at' => 'after',
				'of' => 'gap',
			]
		);

		$this->add_control(
			'wrap_css',
			[
				'label'   => esc_html__( 'Wrap CSS', 'hellix-elementor' ),
				'type'    => Controls_Manager::TEXT,
				'default' => esc_html__( '-r-120', 'hellix-elementor' ),
			]
		);

		$this->parent->end_injection();
	}

	/**
	 * Render the post.
	 */
	public function render_post() {
		$settings       = $this->parent->get_settings_for_display();
		$portfolio_tags = get_the_terms( get_the_ID(), 'jetpack-portfolio-type' );
		$groups         = '';
		$groups_arr     = [];
		$padding_class  = 'portfolioCard__content ';

		if ( '-col-4' === $settings['column'] ) {
			$padding_class .= 'px-20 py-20';
			$margin_class   = 'mt-4';
		} else {
			$padding_class .= 'px-30 py-30';
			$margin_class   = 'mt-8';

		}
		$args = [
			'margin'  => $margin_class,
			'padding' => $padding_class,
		];

		if ( is_array( $portfolio_tags ) ) {
			foreach ( $portfolio_tags as $portfolio_tag ) {
				$groups_arr[] = $portfolio_tag->slug;
			}
		}

		$groups   = implode( ' ', $groups_arr );
		$wrap_css = $this->get_instance_value( 'wrap_css' );
		?>
		<div class='masonry__item hx-article <?php echo esc_attr( $wrap_css ); ?> <?php echo esc_attr( $groups ); ?>'>
			<?php
			if ( $this->get_instance_value( 'style' ) === 'style-v1' ) {
				get_template_part( 'templates/portfolio/content-portfolio/loop/loop-portfolio', 'v1', $args );
			} else {
				get_template_part( 'templates/portfolio/content-portfolio/loop/loop-portfolio', 'v7', $args );
			}
			?>
		</div>
		<?php

	}
}

