<?php
namespace HellixElementor\Modules\Posts\Skins;

use Elementor\Controls_Manager;
use Elementor\Core\Kits\Documents\Tabs\Global_Colors;
use Elementor\Core\Kits\Documents\Tabs\Global_Typography;
use Elementor\Group_Control_Image_Size;
use Elementor\Group_Control_Typography;
use Elementor\Widget_Base;
use Elementor\Skin_Base as Elementor_Skin_Base;
use HellixElementor;
use HellixElementor\Plugin;
use HellixElementor\Core\Utils as HX_Utils;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * The Protfolio Style 5.
 */
class Skin_Portfolio_Style_6 extends Skin_Portfolio_Base {

	/**
	 * Get the name of the widget.
	 *
	 * @return string
	 */
	public function get_id() {
		return 'portfolio-style-6';
	}

	/**
	 * Get the title of the skin.
	 *
	 * @return string
	 */
	public function get_title() {
		return esc_html__( 'Portfolio Style 6', 'hellix-elementor' );
	}

	/**
	 * Render Loop Header.
	 *
	 * @param string $settings The settings instance.
	 */
	protected function render_loop_header( $settings ) {
		$widget  = $this->parent;
		$padding = '';
		$classes = [
			'masonry',
			'elementor-posts-container',
		];

		if ( isset( $settings['column'] ) && ! empty( $settings['column'] ) ) {
			$classes[] .= $settings['column'];
		}
		if ( isset( $settings['gap'] ) && ! empty( $settings['gap'] ) ) {
			$classes[] .= $settings['gap'];
		}

		if ( isset( $settings['padding'] ) && ! empty( $settings['padding'] ) ) {
			$padding = $settings['padding'];
		}

		$wp_query = $this->parent->get_query();

		$this->parent->add_render_attribute(
			'layout',
			[
				'class' => $classes,
			]
		);

		?>
		<div class="section-filter <?php echo esc_attr( $padding ); ?>">
			<div class="container">
				  <div class="row y-gap-32 justify-content-center">
					<div class="col-auto text-center">
						  <div class="sectionHeading -top-line">
							<span class="sectionHeading__subtitle"><?php echo esc_html( $settings['section_subtitle'] ); ?></span>
							<h2 class="sectionHeading__title text-black"><?php echo esc_html( $settings['section_title'] ); ?></h2>
						  </div>
						<?php
						if ( 'yes' === $settings['filters'] ) {
							$this->portfolio_filters();
						}
						?>
					</div>
				  </div>
			</div>
			<div class="container mt-64">
				  <div <?php $widget->print_render_attribute_string( 'layout' ); ?>>
					<div class="masonry__sizer"></div>
					<?php
	}

	/**
	 * Render loop footer.
	 */
	public function render_loop_footer() {
		?>
				</div>
			</div>
		</div>
		<?php
		$this->parent->hellix_pagination();
	}


	/**
	 * Render the post.
	 */
	public function render_post() {
		$settings       = $this->parent->get_settings_for_display();
		$portfolio_tags = get_the_terms( get_the_ID(), 'jetpack-portfolio-type' );
		$groups         = '';
		$groups_arr     = [];
		$padding_class  = 'portfolioCard__content bg-black text-center ';

		if ( '-col-4' === $settings['column'] ) {
			$padding_class .= 'px-20 py-20';
			$margin_class   = 'mt-4';
		} else {
			$padding_class .= 'px-30 py-30';
			$margin_class   = 'mt-8';

		}
		$args = [
			'margin'  => $margin_class,
			'padding' => $padding_class,
		];

		if ( is_array( $portfolio_tags ) ) {
			foreach ( $portfolio_tags as $portfolio_tag ) {
				$groups_arr[] = $portfolio_tag->slug;
			}
		}

		$groups = implode( ' ', $groups_arr );
		?>
		<div class='masonry__item -no-ratio hx-article <?php echo esc_attr( $groups ); ?>'>
			<?php get_template_part( 'templates/portfolio/content-portfolio/loop/loop-portfolio', 'v8', $args ); ?>
		</div>
		<?php

	}
}

