<?php
namespace HellixElementor\Modules\Posts\Skins;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Plugin as ElementorPlugin;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * Grid Skin class.
 */
class Skin_Post_Grid extends Skin_Base {

	/**
	 * Get the ID of the skin.
	 *
	 * @return string
	 */
	public function get_id() {
		return 'hellix-posts-grid';
	}

	/**
	 * Get the title of the skin.
	 *
	 * @return string
	 */
	public function get_title() {
		return esc_html__( 'Grid', 'hellix-elementor' );
	}

	/**
	 * Register controls for this widget.
	 *
	 * @return void
	 */
	protected function _register_controls_actions() {
		add_action( 'elementor/element/hx-posts/section_layout/after_section_end', [ $this, 'add_content_controls' ], 20 );

	}

	 /**
	  * Add Controls to Content Tab.
	  *
	  * @return void
	  */
	public function add_content_controls() {

		$this->parent->start_injection(
			[
				'at' => 'after',
				'of' => '_skin',
			]
		);
			$this->add_control(
				'posts_per_page',
				[
					'label'   => esc_html__( 'Posts Per Page', 'hellix-elementor' ),
					'type'    => Controls_Manager::NUMBER,
					'default' => 6,
				]
			);
			$this->add_control(
				'enable_term_filter',
				[
					'label'     => esc_html__( 'Enable Filters', 'hellix-elementor' ),
					'type'      => Controls_Manager::SWITCHER,
					'label_on'  => esc_html__( 'Show', 'hellix-elementor' ),
					'label_off' => esc_html__( 'Hide', 'hellix-elementor' ),
					'default'   => 'yes',
				]
			);
		$this->parent->end_injection();
	}

	/**
	 * Render loop header.
	 */
	protected function render_loop_header() {
		// $this->parent->add_render_attribute( 'container', array( 'class' => 'masonry -gap-32 -col-3 layout-pt-sm js-masonry js-masonry-no-filter' ) );
		// parent::render_loop_header();
		?>
		<div class="section-filter px-16">
		<?php
		$enable_term_filters = $this->get_instance_value( 'enable_term_filter' );
		if ( 'yes' === $enable_term_filters ) {
			$this->render_post_filters();
		}
		?>
		<div class="masonry -gap-32 -col-3 layout-pt-sm js-masonry js-masonry-no-filter elementor-posts-container">
				<div class="masonry__sizer"></div>
		<?php
	}

	/**
	 * Render loop post.
	 */
	public function render_post() {
		$post_cats  = get_the_terms( get_the_ID(), 'category' );
		$groups     = '';
		$groups_arr = [];

		if ( is_array( $post_cats ) ) {
			foreach ( $post_cats as $post_cat ) {
				$groups_arr[] = $post_cat->slug;
			}
		}

		$groups = implode( ' ', $groups_arr );
		?>
		<div class="masonry__item -no-ratio hx-article <?php echo esc_attr( $groups ); ?>">
		<?php
		get_template_part( 'templates/blog/content', 'grid' );
		?>
		</div>
		<?php
	}

	/**
	 * Render.
	 */
	public function render() {
		$this->parent->query_posts();
		$query = $this->parent->get_query();

		if ( ! $query->found_posts ) {
			return;
		}

		$this->render_loop_header();

		// It's the global `wp_query` it self. and the loop was started from the theme.
		if ( $query->in_the_loop ) {
			$this->current_permalink = get_permalink();
			$this->render_post();
		} else {
			while ( $query->have_posts() ) {
				$query->the_post();

				$this->current_permalink = get_permalink();
				$this->render_post();
			}
		}

		wp_reset_postdata();
		$this->render_loop_footer();
		$this->render_script();

	}

	/**
	 * Render post filters.
	 */
	protected function render_post_filters() {
		$portfolio_cats = array();
		$query          = $this->parent->get_query();
		while ( $query->have_posts() ) :
			$query->the_post();
			$post_types = get_the_terms( get_the_ID(), 'category' );
			if ( ! $post_types || is_wp_error( $post_types ) ) {
				$post_types = array();
			}

			$post_types = array_values( $post_types );

			foreach ( array_keys( $post_types ) as $key ) {
				_make_cat_compat( $post_types[ $key ] );
			}

			foreach ( $post_types as $post_type ) {
				$post_cats[ $post_type->slug ] = $post_type->name;
			}

		endwhile;
		?>
		<div class="row justify-content-center">
			<div class="col-auto">
				<div class="filter-button-group text-dark fw-500 mt-32">         
					<button class="button mr-20 btn-active" data-filter="*">All</button>
		   
					<?php
					foreach ( $post_cats as $key => $post_cat ) :
						$category_id   = get_cat_ID( $post_cat );
						$category_link = get_category_link( $category_id );
						?>
							<button class="button mr-20" data-filter=".<?php echo esc_attr( $key ); ?>" >
							<?php echo esc_html( $post_cat ); ?>
							</button>
					<?php endforeach; ?>
				</div>
			</div>
		</div>
		<?php
	}

	/**
	 * Render loop filters.
	 */
	protected function render_loop_footer() {
		?>
		</div>
	</div>
		<?php
		$this->parent->hellix_pagination();
	}

	/**
	 * Render script in the editor.
	 */
	public function render_script() {
		if ( ElementorPlugin::$instance->editor->is_edit_mode() ) :
			?>
			<script type="text/javascript">
				
				/**
				 * Editor Slider Load.
				 */
				function masonryGridInit() {

					var grids = document.querySelectorAll('.js-masonry.js-masonry-no-filter');

					if (!grids.length) {
						return;
					}

					for (let i = 0; i < grids.length; i++) {
						new Isotope(grids[i], {
							  itemSelector: '.masonry__item',
							  percentPosition: true,

							  layoutMode: 'packery',
							  packery: {
								columnWidth: '.masonry__sizer',
							  },
						});
					}
				}

				function masonryFilterInit() {

					  const filterGrids = document.querySelectorAll('.section-filter');

					if (!filterGrids.length) {
						return;
					}

					  for (let i = 0; i < filterGrids.length; i++) {
						const el = filterGrids[i];

						let iso = new Isotope(el.querySelector('.masonry'), {
							  itemSelector: '.masonry__item',
							  percentPosition: true,
							  // horizontalOrder: true,

							  layoutMode: 'packery',
							  packery: {
								columnWidth: '.masonry__sizer',
							  },
						});


						const filterButtons = el.querySelectorAll(".filter-button-group button");
					  
						for (let i = 0; i < filterButtons.length; i++) {
						  const el = filterButtons[i];

						  el.addEventListener("click", () => {

							let someom = iso.getItemElements();
							someom.forEach(el => {
							  el.classList.remove('is-active');
							});

							filterButtons.forEach(button => button.classList.remove('btn-active'));
							el.classList.add('btn-active');

							let filterValue = el.getAttribute('data-filter');
							iso.arrange({ filter: filterValue });

						  });
						}
					}
				}

				function lazyLoading() {
					  if (!document.querySelector('.js-lazy')) {
						return;
					}

					new LazyLoad({
						elements_selector: ".js-lazy",
					});
				}
				
				lazyLoading();
				masonryGridInit();
				masonryFilterInit();
			</script>
			<?php
		endif;
	}
}
