<?php
namespace HellixElementor\Modules\Posts\Widgets;

use Elementor\Core\Kits\Documents\Tabs\Global_Colors;
use Elementor\Core\Kits\Documents\Tabs\Global_Typography;
use Elementor\Group_Control_Image_Size;
use Elementor\Group_Control_Typography;
use HellixElementor\Base\Base_Widget;
use HellixElementor\Modules\QueryControl\Module as Module_Query;
use HellixElementor\Modules\QueryControl\Controls\Group_Control_Related;
use Elementor\Controls_Manager;
use HellixElementor\Modules\Posts\Skins;
use Elementor\Plugin;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * Class Portfolio
 */
class Portfolio extends Posts_Base {

	/**
	 * Query.
	 *
	 * @var array
	 */
	protected $_query = null;

	/**
	 * Template Content.
	 *
	 * @var bool
	 */
	protected $_has_template_content = false;

	/**
	 * Get the name of the widget.
	 *
	 * @return string
	 */
	public function get_name() {
		return 'hx-portfolio';
	}

	/**
	 * Get the title of the widget.
	 *
	 * @return string
	 */
	public function get_title() {
		return __( 'Portfolio', 'hellix-elementor' );
	}

	/**
	 * Get the icon for the widget.
	 *
	 * @return string
	 */
	public function get_icon() {
		return 'eicon-gallery-grid';
	}

	/**
	 * Get the keywords associated with the widget.
	 *
	 * @return array
	 */
	public function get_keywords() {
		return [ 'posts', 'cpt', 'item', 'loop', 'query', 'portfolio', 'custom post type' ];
	}

	/**
	 * Get post type object on import.
	 *
	 * @param array $element settings posttype.
	 * @return array
	 */
	public function on_import( $element ) {
		if ( ! get_post_type_object( $element['settings']['posts_post_type'] ) ) {
			$element['settings']['posts_post_type'] = 'post';
		}

		return $element;
	}

	/**
	 * Register the Skins with the widget.
	 *
	 * @return void
	 */
	protected function register_skins() {

		$this->add_skin( new Skins\Skin_portfolio_style_1( $this ) );
		$this->add_skin( new Skins\Skin_portfolio_style_2( $this ) );
		$this->add_skin( new Skins\Skin_portfolio_style_3( $this ) );
		$this->add_skin( new Skins\Skin_portfolio_style_4( $this ) );
		$this->add_skin( new Skins\Skin_portfolio_style_5( $this ) );
		$this->add_skin( new Skins\Skin_portfolio_style_6( $this ) );
	}

	/**
	 * Get Query.
	 */
	public function get_query() {
		return $this->_query;
	}

	/**
	 * Register controls for this widget.
	 *
	 * @return void
	 */
	protected function register_controls() {
		$this->register_query_section_controls();
		$this->register_pagination_section_controls();
	}

	// abstract public function query_posts();.

	/**
	 * Gets Posts per page
	 */
	public function query_posts() {

		$query_args = [
			'posts_per_page' => $this->get_settings( 'posts_per_page' ),
			'paged'          => $this->get_current_page(),
		];

		$elementor_query = Module_Query::instance();
		$this->_query    = $elementor_query->get_query( $this, 'posts', $query_args, [] );
	}

	/**
	 * Register query controls for this widget.
	 *
	 * @return void
	 */
	private function register_query_section_controls() {
		$this->start_controls_section(
			'section_layout',
			[
				'label' => esc_html__( 'Layout', 'hellix-elementor' ),
				'tab'   => Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_control(
			'posts_per_page',
			[
				'label'   => esc_html__( 'Posts Per Page', 'hellix-elementor' ),
				'type'    => Controls_Manager::NUMBER,
				'default' => 6,
			]
		);

		$this->add_control(
			'filters',
			[
				'label'     => esc_html__( 'Filter ?', 'hellix-elementor' ),
				'type'      => Controls_Manager::SWITCHER,
				'label_on'  => esc_html__( 'Enable', 'hellix-elementor' ),
				'label_off' => esc_html__( 'Disable', 'hellix-elementor' ),
				'default'   => 'yes',
				'condition' => [
					'_skin!' => [ 'portfolio-style-3' ],
				],
			]
		);

		$this->add_control(
			'container',
			[
				'label'       => esc_html__( 'Container ?', 'hellix-elementor' ),
				'type'        => Controls_Manager::SWITCHER,
				'description' => esc_html__( 'Enable container for filter', 'hellix-elementor' ),
				'label_on'    => esc_html__( 'Enable', 'hellix-elementor' ),
				'label_off'   => esc_html__( 'Disable', 'hellix-elementor' ),
				'default'     => 'yes',
				'condition'   => [
					'filters' => 'yes',
					'_skin!'  => [ 'portfolio-style-3', 'portfolio-style-6', 'portfolio-style-5' ],
				],
			]
		);

		$this->add_control(
			'heading',
			[
				'label'     => esc_html__( 'Section Heading ?', 'hellix-elementor' ),
				'type'      => Controls_Manager::SWITCHER,
				'label_on'  => esc_html__( 'Enable', 'hellix-elementor' ),
				'label_off' => esc_html__( 'Disable', 'hellix-elementor' ),
				'default'   => 'yes',
				'condition' => [
					'_skin!' => [ 'portfolio-style-3', 'portfolio-style-5' ],
				],
			]
		);

		$this->add_control(
			'section_subtitle',
			[
				'label'     => esc_html__( 'Section Subtitle', 'hellix-elementor' ),
				'type'      => Controls_Manager::TEXT,
				'dynamic'   => [
					'active' => true,
				],
				'default'   => esc_html( 'PROJECTS' ),
				'condition' => [
					'heading' => 'yes',
					'_skin!'  => [ 'portfolio-style-3', 'portfolio-style-5' ],
				],
			]
		);

		$this->add_control(
			'section_title',
			[
				'label'     => esc_html__( 'Section Title', 'hellix-elementor' ),
				'type'      => Controls_Manager::TEXT,
				'default'   => esc_html( 'Featured Works' ),
				'dynamic'   => [
					'active' => true,
				],
				'condition' => [
					'heading' => 'yes',
					'_skin!'  => [ 'portfolio-style-3', 'portfolio-style-5' ],
				],
			]
		);

		$this->add_control(
			'column',
			[
				'label'     => esc_html__( 'Column', 'hellix-elementor' ),
				'type'      => Controls_Manager::SELECT,
				'default'   => '-col-3',
				'options'   => [
					'-col-2' => esc_html__( '2', 'hellix-elementor' ),
					'-col-3' => esc_html__( '3', 'hellix-elementor' ),
					'-col-4' => esc_html__( '4', 'hellix-elementor' ),
				],
				'condition' => [
					'_skin!' => [ 'portfolio-style-3' ],
				],
			]
		);

		$this->add_control(
			'gap',
			[
				'label'     => esc_html__( 'Gap', 'hellix-elementor' ),
				'type'      => Controls_Manager::SELECT,
				'default'   => '-gap-32',
				'options'   => [
					'-gap-16' => esc_html__( 'Gap 16', 'hellix-elementor' ),
					'-gap-32' => esc_html__( 'Gap 32', 'hellix-elementor' ),
					''        => esc_html__( 'No Gap', 'hellix-elementor' ),
				],
				'condition' => [
					'_skin!' => [ 'portfolio-style-3' ],
				],
			]
		);

		$this->add_control(
			'padding',
			[
				'label'     => esc_html__( 'Section Padding', 'hellix-elementor' ),
				'type'      => Controls_Manager::SELECT,
				'default'   => 'px-16',
				'options'   => [
					'px-16' => esc_html__( 'px-16', 'hellix-elementor' ),
					'px-32' => esc_html__( 'px-32', 'hellix-elementor' ),
					'px-0'  => esc_html__( 'None', 'hellix-elementor' ),
				],
				'condition' => [
					'_skin!' => [ 'portfolio-style-3' ],
				],
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'section_query',
			[
				'label' => esc_html__( 'Query', 'hellix-elementor' ),
				'tab'   => Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_group_control(
			Group_Control_Related::get_type(),
			[
				'name'      => 'posts',
				'presets'   => [ 'full' ],
				'exclude'   => [
					'posts_per_page', // use the one from Layout section.
				],
				'post_type' => 'jetpack-portfolio',
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'portfolio_section_style',
			[
				'label'     => esc_html__( 'Button', 'hellix-elementor' ),
				'tab'       => Controls_Manager::TAB_STYLE,
				'condition' => [
					'enable_button' => [ 'yes' ],
				],
			]
		);

		$this->add_control(
			'portfolio_button_type',
			[
				'label'   => esc_html__( 'Type', 'hellix-elementor' ),
				'type'    => Controls_Manager::SELECT,
				'default' => 'dark',
				'options' => [
					'white'     => esc_html__( 'White', 'hellix-elementor' ),
					'dark'      => esc_html__( 'Dark', 'hellix-elementor' ),
					'secondary' => esc_html__( 'Secondary', 'hellix-elementor' ),
					'accent'    => esc_html__( 'Accent', 'hellix-elementor' ),
					'grey'      => esc_html__( 'Grey', 'hellix-elementor' ),
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'     => 'btn_typography',
				'global'   => [
					'default' => Global_Typography::TYPOGRAPHY_ACCENT,
				],
				'selector' => '{{WRAPPER}} .button__text_color',
			]
		);

		$this->add_control(
			'portfolio_button_text_color',
			[
				'label'     => esc_html__( 'Text Color', 'hellix-elementor' ),
				'type'      => Controls_Manager::COLOR,
				'default'   => '#FFFFFF',
				'selectors' => [
					'{{WRAPPER}} .button__text_color' => 'fill: {{VALUE}}; color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'button_bg_color',
			[
				'label'     => esc_html__( 'Background Color', 'hellix-elementor' ),
				'type'      => Controls_Manager::COLOR,
				'default'   => '',
				'selectors' => [
					'{{WRAPPER}} .button-color' => 'background-color:{{VALUE}} !important;',
				],
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'section_heading_title_style',
			[
				'label'     => esc_html__( 'Heading Title', 'hellix-elementor' ),
				'tab'       => Controls_Manager::TAB_STYLE,
				'condition' => [
					'heading' => 'yes',
				],
			]
		);

		$this->add_control(
			'heading_title_color',
			[
				'label'     => esc_html__( 'Color', 'hellix-elementor' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .sectionHeading__title' => 'color: {{VALUE}} !important;',
				],
				'global'    => [
					'default' => Global_Colors::COLOR_TEXT,
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'     => 'heading_title_typography',
				'selector' => '{{WRAPPER}} .sectionHeading__title',
				'global'   => [
					'default' => Global_Typography::TYPOGRAPHY_TEXT,
				],
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'section_sub_title_style',
			[
				'label'     => esc_html__( 'Heading Sub Tilte', 'hellix-elementor' ),
				'tab'       => Controls_Manager::TAB_STYLE,
				'condition' => [
					'heading' => 'yes',
				],
			]
		);

		$this->add_control(
			'sub_title_color',
			[
				'label'     => esc_html__( 'Color', 'hellix-elementor' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .sectionHeading__subtitle' => 'color: {{VALUE}}',
				],
				'global'    => [
					'default' => Global_Colors::COLOR_TEXT,
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'     => 'sub_title_typography',
				'selector' => '{{WRAPPER}} .sectionHeading__subtitle',
				'global'   => [
					'default' => Global_Typography::TYPOGRAPHY_TEXT,
				],
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'section_design_filter',
			[
				'label'     => esc_html__( 'Filter Bar', 'hellix-elementor' ),
				'tab'       => Controls_Manager::TAB_STYLE,
				'condition' => [
					'filters' => 'yes',
				],
			]
		);

		$this->add_control(
			'color_filter',
			[
				'label'     => esc_html__( 'Color', 'hellix-elementor' ),
				'type'      => Controls_Manager::COLOR,
				'global'    => [
					'default' => Global_Colors::COLOR_TEXT,
				],
				'selectors' => [
					'{{WRAPPER}} .button' => 'color: {{VALUE}} !important;',
				],
			]
		);

		$this->add_control(
			'color_filter_active',
			[
				'label'     => esc_html__( 'Active Color', 'hellix-elementor' ),
				'type'      => Controls_Manager::COLOR,
				'global'    => [
					'default' => Global_Colors::COLOR_PRIMARY,
				],
				'selectors' => [
					'{{WRAPPER}} .button.btn-active' => 'color: {{VALUE}} !important;',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'     => 'typography_filter',
				'global'   => [
					'default' => Global_Typography::TYPOGRAPHY_PRIMARY,
				],
				'selector' => '{{WRAPPER}} .button',
			]
		);

		$this->end_controls_section();
	}

	/**
	 * Render script in the editor.
	 */
	public function render_script() {
		if ( Plugin::$instance->editor->is_edit_mode() ) :
			?>
			<script type="text/javascript">
				
				/**
				 * Editor Slider Load.
				 */
				function masonryGridInit() {

					var grids = document.querySelectorAll('.js-masonry.js-masonry-no-filter');

					if (!grids.length) {
						return;
					}

					for (let i = 0; i < grids.length; i++) {
						new Isotope(grids[i], {
							  itemSelector: '.masonry__item',
							  percentPosition: true,

							  layoutMode: 'packery',
							  packery: {
								columnWidth: '.masonry__sizer',
							  },
						});
					}
				}

				function masonryFilterInit() {

					  const filterGrids = document.querySelectorAll('.section-filter');

					if (!filterGrids.length) {
						return;
					}

					  for (let i = 0; i < filterGrids.length; i++) {
						const el = filterGrids[i];

						let iso = new Isotope(el.querySelector('.masonry'), {
							  itemSelector: '.masonry__item',
							  percentPosition: true,
							  // horizontalOrder: true,

							  layoutMode: 'packery',
							  packery: {
								columnWidth: '.masonry__sizer',
							  },
						});


						const filterButtons = el.querySelectorAll(".filter-button-group button");
					  
						for (let i = 0; i < filterButtons.length; i++) {
						  const el = filterButtons[i];

						  el.addEventListener("click", () => {

							let someom = iso.getItemElements();
							someom.forEach(el => {
							  el.classList.remove('is-active');
							});

							filterButtons.forEach(button => button.classList.remove('btn-active'));
							el.classList.add('btn-active');

							let filterValue = el.getAttribute('data-filter');
							iso.arrange({ filter: filterValue });

						  });
						}
					}
				}

				function lazyLoading() {
					  if (!document.querySelector('.js-lazy')) {
						return;
					}

					new LazyLoad({
						elements_selector: ".js-lazy",
					});
				}
				
				lazyLoading();
				masonryGridInit();
				masonryFilterInit();
			</script>
			<?php
		endif;
	}
}
