<?php
namespace HellixElementor\Modules\SocialIcons\Skins;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}


use Elementor;
use Elementor\Skin_Base;
use Elementor\Control_Media;
use Elementor\Utils;
use Elementor\Group_Control_Image_Size;
use Elementor\Controls_Manager;
use HellixElementor\Core\Utils as HX_Utils;
use Elementor\Icons_Manager;

/**
 * The Social Icon skin.
 */
class Skin_Hellix extends Skin_Base {

	/**
	 * Setup the skin
	 *
	 * @param Elementor\Widget_Base $parent The social icon widget.
	 */
	public function __construct( Elementor\Widget_Base $parent ) {
		parent::__construct( $parent );
		add_filter( 'elementor/widget/print_template', [ $this, 'skin_print_template' ], 10, 2 );
		add_action( 'elementor/element/social-icons/section_social_icon/before_section_end', [ $this, 'section_skin_hellix_controls' ], 10 );
		add_action( 'elementor/element/social-icons/section_social_style/before_section_end', [ $this, 'style_image_controls' ] );
		add_action( 'elementor/element/social-icons/section_social_hover/after_section_end', [ $this, 'style_content_controls' ] );
	}

	/**
	 * Get the name of the widget.
	 *
	 * @return string
	 */
	public function get_id() {
		return 'skin-hellix';
	}

	/**
	 * Get the title of the skin.
	 *
	 * @return string
	 */
	public function get_title() {
		return esc_html__( 'Hellix', 'hellix-elementor' );
	}

	/**
	 * Skin Print Template.
	 *
	 * @param string                $content The skin output string.
	 * @param Elementor\Widget_Base $widget The widget.
	 *
	 * @return string
	 */
	public function skin_print_template( $content, $widget ) {
		if ( 'social-icons' === $widget->get_name() ) {
			return '';
		}
		return $content;
	}

	/**
	 * Style Content Controls.
	 *
	 * @param  Elementor\Widget_Base $widget The Widget.
	 */
	public function style_content_controls( Elementor\Widget_Base $widget ) {
		$this->parent = $widget;
		$widget->update_control(
			'section_social_hover',
			[
				'condition' => [ '_skin' => '' ],
			]
		);
	}

	/**
	 * Style image Controls.
	 *
	 * @param  Elementor\Widget_Base $widget The Widget.
	 */
	public function style_image_controls( Elementor\Widget_Base $widget ) {
		$this->parent     = $widget;
		$disable_controls = [
			'icon_color',
			'icon_primary_color',
			'icon_secondary_color',
			'icon_size',
			'icon_padding',
			'icon_spacing',
			'row_gap',
			'border_radius',
			'image_border_typography',
		];

		foreach ( $disable_controls as $control ) {
			$widget->update_control(
				$control,
				[
					'condition' => [
						'_skin' => '',
					],
				]
			);
		}

		$widget->add_control(
			'hx-icon_color',
			[
				'label'     => esc_html__( 'Color', 'hellix-elementor' ),
				'type'      => Controls_Manager::COLOR,
				'default'   => '#000000',
				'selectors' => [
					'{{WRAPPER}} .footer__socials_content a' => 'color: {{VALUE}} !important;',
					'{{WRAPPER}} .footer__socials_content a:hover' => 'border-color: {{VALUE}} !important;',
					'{{WRAPPER}} .elementor-social-icon:hover' => 'color: {{VALUE}} !important;',
				],
			],
			[
				'position' => [
					'at' => 'after',
					'of' => 'section_social_style',
				],
			]
		);
		$widget->add_control(
			'hx-bg-icon_color',
			[
				'label'     => esc_html__( 'Background Color', 'hellix-elementor' ),
				'type'      => Controls_Manager::COLOR,
				'default'   => '#fff',
				'selectors' => [
					'{{WRAPPER}} .hx-elementor-social-icon' => 'background-color: {{VALUE}} !important;',
				],
			],
			[
				'position' => [
					'at' => 'after',
					'of' => 'section_social_style',
				],
			]
		);
	}

	/**
	 * Section skin hellix controls.
	 *
	 * @param  Elementor\Widget_Base $widget the widget.
	 */
	public function section_skin_hellix_controls( Elementor\Widget_Base $widget ) {

		$this->parent = $widget;

		$disable_controls = [ 'shape', 'align', 'columns' ];

		foreach ( $disable_controls as $control ) {
			$widget->update_control(
				$control,
				[
					'condition' => [
						'_skin' => '',
					],
				]
			);
		}

		$this->parent->start_injection(
			[
				'at' => 'after',
				'of' => '_skin',
			]
		);

		$this->parent->add_control(
			'display_style',
			[
				'type'      => Controls_Manager::SELECT,
				'label'     => esc_html__( 'Style Variation', 'hellix-elementor' ),
				'default'   => 'default',
				'options'   => [
					'default'  => esc_html__( 'Style 1', 'hellix-elementor' ),
					'style_v2' => esc_html__( 'Style 2', 'hellix-elementor' ),
				],
				'condition' => [
					'_skin' => 'skin-hellix',
				],
			]
		);

		$this->parent->end_injection();
	}

	/**
	 * Render the widget in the frontend.
	 */
	public function render() {
		$widget   = $this->parent;
		$settings = $widget->get_settings_for_display();

		$skin_control_ids = [
			'display_style',
		];

		$skin_settings = [];

		foreach ( $skin_control_ids as $skin_control_id ) {
			$skin_settings[ $skin_control_id ] = $this->get_instance_value( $skin_control_id );
		}
		?>
		<?php if ( 'default' === $settings['display_style'] ) : ?>
		<div class="footer__socials_content">
		<?php endif; ?>
		<?php
		if ( 'default' !== $settings['display_style'] ) {
			?>
			<div class="soon__socials socials">
				<div class="socials__wrap">
				<?php
		}
		foreach ( $settings['social_icon_list'] as $index => $item ) {

			$link_key = 'link_' . $index;

			$widget->add_link_attributes( $link_key, $item['link'] );
			if ( 'default' !== $settings['display_style'] ) {
				$widget->add_render_attribute( $link_key, 'data-barba' );
				$widget->add_render_attribute( $link_key, 'class', 'text-white' );
			}

			?>
						<a <?php $widget->print_render_attribute_string( $link_key ); ?>>
				<?php
				Icons_Manager::render_icon(
					$item['social_icon'],
					[
						'aria-hidden' => 'true',
						'class'       => 'hx-elementor-social-icon elementor-social-icon',
					]
				);
				?>
						</a>
		<?php } ?>
				<?php
				if ( 'default' !== $settings['display_style'] ) {
					?>
				</div>
			</div>
					<?php
				}
				?>
		<?php if ( 'default' === $settings['display_style'] ) : ?>
		</div>
		<?php endif; ?>
		<?php
	}

}
